@@ -19,13 +19,13 @@ import java.util.Optional;
 import java.util.function.Supplier;
 
 import javax.enterprise.context.Dependent;
+import javax.enterprise.event.Event;
 import javax.inject.Inject;
-import javax.inject.Named;
 
 import com.ait.lienzo.client.core.types.Transform;
 import com.google.gwt.event.dom.client.ClickEvent;
 import org.jboss.errai.common.client.dom.Anchor;
-import org.jboss.errai.common.client.dom.Heading;
+import org.jboss.errai.common.client.dom.Span;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.jboss.errai.ui.shared.api.annotations.DataField;
 import org.jboss.errai.ui.shared.api.annotations.EventHandler;
@@ -34,20 +34,32 @@ import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.session.DMNSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.BoundaryTransformMediator;
 import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
+import org.kie.workbench.common.dmn.client.widgets.grid.columns.KeyboardOperationEscapeGridCell;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanelContainer;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.session.Session;
-import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLienzoPanel;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.BaseGridWidgetKeyboardHandler;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperation;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationEditCell;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationInvokeContextMenuForSelectedCell;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationMoveDown;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationMoveLeft;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationMoveRight;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationMoveUp;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.TransformMediator;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.impl.RestrictedMousePanMediator;
 
@@ -59,67 +71,77 @@ public class ExpressionEditorViewImpl implements ExpressionEditorView {
 
     private ExpressionEditorView.Presenter presenter;
 
-    @DataField("returnToDRG")
-    private Anchor returnToDRG;
+    @DataField("returnToLink")
+    private Anchor returnToLink;
+
+    @DataField("expressionName")
+    private Span expressionName;
 
     @DataField("expressionType")
-    private Heading expressionType;
+    private Span expressionType;
 
-    private ExpressionContainerGrid expressionContainerGrid;
+    @DataField("dmn-table")
+    private DMNGridPanelContainer gridPanelContainer;
+
+    private TranslationService translationService;
+    private ListSelectorView.Presenter listSelector;
+    private SessionManager sessionManager;
+    private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
+    private DefaultCanvasCommandFactory canvasCommandFactory;
+    private Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent;
+    private Event<DomainObjectSelectionEvent> domainObjectSelectionEvent;
 
     private DMNGridPanel gridPanel;
     private DMNGridLayer gridLayer;
-    private RestrictedMousePanMediator mousePanMediator;
-
     private CellEditorControlsView.Presenter cellEditorControls;
-    private TranslationService translationService;
-    private ListSelectorView.Presenter listSelector;
-
-    private SessionManager sessionManager;
-    private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
-    private Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private RestrictedMousePanMediator mousePanMediator;
+    private ExpressionContainerGrid expressionContainerGrid;
 
     public ExpressionEditorViewImpl() {
         //CDI proxy
     }
 
     @Inject
-    public ExpressionEditorViewImpl(final Anchor returnToDRG,
-                                    final @Named("h2") Heading expressionType,
-                                    final @DMNEditor DMNGridPanel gridPanel,
-                                    final @DMNEditor DMNGridLayer gridLayer,
-                                    final @DMNEditor RestrictedMousePanMediator mousePanMediator,
-                                    final CellEditorControlsView.Presenter cellEditorControls,
+    public ExpressionEditorViewImpl(final Anchor returnToLink,
+                                    final Span expressionName,
+                                    final Span expressionType,
+                                    final @DMNEditor DMNGridPanelContainer gridPanelContainer,
                                     final TranslationService translationService,
                                     final ListSelectorView.Presenter listSelector,
                                     final SessionManager sessionManager,
                                     final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                    final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
-        this.returnToDRG = returnToDRG;
+                                    final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
+                                    final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
+                                    final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                                    final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent) {
+        this.returnToLink = returnToLink;
+        this.expressionName = expressionName;
         this.expressionType = expressionType;
+        this.gridPanelContainer = gridPanelContainer;
 
-        this.gridPanel = gridPanel;
-        this.gridLayer = gridLayer;
-        this.mousePanMediator = mousePanMediator;
-
-        this.cellEditorControls = cellEditorControls;
         this.translationService = translationService;
         this.listSelector = listSelector;
 
         this.sessionManager = sessionManager;
         this.sessionCommandManager = sessionCommandManager;
+        this.canvasCommandFactory = canvasCommandFactory;
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
-    }
-
-    @DataField("dmn-table")
-    @SuppressWarnings("unused")
-    public GridLienzoPanel getGridPanel() {
-        return gridPanel;
+        this.refreshFormPropertiesEvent = refreshFormPropertiesEvent;
+        this.domainObjectSelectionEvent = domainObjectSelectionEvent;
     }
 
     @Override
     public void init(final ExpressionEditorView.Presenter presenter) {
         this.presenter = presenter;
+    }
+
+    @Override
+    public void bind(final DMNSession session) {
+        this.gridPanel = session.getGridPanel();
+        this.gridLayer = session.getGridLayer();
+        this.cellEditorControls = session.getCellEditorControls();
+        this.mousePanMediator = session.getMousePanMediator();
 
         setupGridPanel();
         setupGridWidget();
@@ -128,10 +150,27 @@ public class ExpressionEditorViewImpl implements ExpressionEditorView {
 
     protected void setupGridPanel() {
         final Transform transform = new Transform().scale(VP_SCALE);
+        gridPanel.getElement().setId("dmn_container_" + com.google.gwt.dom.client.Document.get().createUniqueId());
         gridPanel.getViewport().setTransform(transform);
         gridPanel.add(gridLayer);
 
-        gridPanel.getElement().setId("dmn_container_" + com.google.gwt.dom.client.Document.get().createUniqueId());
+        final BaseGridWidgetKeyboardHandler handler = new BaseGridWidgetKeyboardHandler(gridLayer);
+        addKeyboardOperation(handler, new KeyboardOperationEditCell(gridLayer));
+        addKeyboardOperation(handler, new KeyboardOperationEscapeGridCell(gridLayer));
+        addKeyboardOperation(handler, new KeyboardOperationMoveLeft(gridLayer));
+        addKeyboardOperation(handler, new KeyboardOperationMoveRight(gridLayer));
+        addKeyboardOperation(handler, new KeyboardOperationMoveUp(gridLayer));
+        addKeyboardOperation(handler, new KeyboardOperationMoveDown(gridLayer));
+        addKeyboardOperation(handler, new KeyboardOperationInvokeContextMenuForSelectedCell(gridLayer));
+        gridPanel.addKeyDownHandler(handler);
+
+        gridPanelContainer.clear();
+        gridPanelContainer.setWidget(gridPanel);
+    }
+
+    void addKeyboardOperation(final BaseGridWidgetKeyboardHandler handler,
+                              final KeyboardOperation operation) {
+        handler.addOperation(operation);
     }
 
     protected void setupGridWidget() {
@@ -141,10 +180,13 @@ public class ExpressionEditorViewImpl implements ExpressionEditorView {
                                                               listSelector,
                                                               sessionManager,
                                                               sessionCommandManager,
+                                                              canvasCommandFactory,
                                                               expressionEditorDefinitionsSupplier,
                                                               getExpressionGridCacheSupplier(),
                                                               this::setExpressionTypeText,
-                                                              this::setReturnToDRGText);
+                                                              this::setExpressionNameText,
+                                                              refreshFormPropertiesEvent,
+                                                              domainObjectSelectionEvent);
         gridLayer.removeAll();
         gridLayer.add(expressionContainerGrid);
         gridLayer.select(expressionContainerGrid);
@@ -167,6 +209,11 @@ public class ExpressionEditorViewImpl implements ExpressionEditorView {
         gridPanel.getViewport().getMediators().push(mousePanMediator);
     }
 
+    @Override
+    public void setReturnToLinkText(final String text) {
+        returnToLink.setTextContent(translationService.format(DMNEditorConstants.ExpressionEditor_ReturnToLink, text));
+    }
+
     @Override
     public void setExpression(final String nodeUUID,
                               final HasExpression hasExpression,
@@ -174,30 +221,37 @@ public class ExpressionEditorViewImpl implements ExpressionEditorView {
         expressionContainerGrid.setExpression(nodeUUID,
                                               hasExpression,
                                               hasName);
-
-        setReturnToDRGText(hasName);
+        setExpressionNameText(hasName);
         setExpressionTypeText(Optional.ofNullable(hasExpression.getExpression()));
     }
 
-    private void setReturnToDRGText(final Optional<HasName> hasName) {
-        hasName.ifPresent(name -> returnToDRG.setTextContent(translationService.format(DMNEditorConstants.ExpressionEditor_ReturnToDRG,
-                                                                                       name.getName().getValue())));
+    @Override
+    public void setExpressionNameText(final Optional<HasName> hasName) {
+        hasName.ifPresent(name -> expressionName.setTextContent(name.getName().getValue()));
     }
 
-    private void setExpressionTypeText(final Optional<Expression> expression) {
-        expressionType.setTextContent(expression.isPresent() ?
-                                              expression.get().getClass().getSimpleName() :
-                                              "<" + translationService.getTranslation(DMNEditorConstants.ExpressionEditor_UndefinedExpressionType) + ">");
+    @Override
+    public void setExpressionTypeText(final Optional<Expression> expression) {
+        final String expressionTypeText = expressionEditorDefinitionsSupplier.get().getExpressionEditorDefinition(expression).get().getName();
+        expressionType.setTextContent(translationService.format(DMNEditorConstants.ExpressionEditor_ExpressionTypeText,
+                                                                expression.isPresent() ?
+                                                                        expressionTypeText :
+                                                                        "<" + expressionTypeText + ">"));
     }
 
     @SuppressWarnings("unused")
-    @EventHandler("returnToDRG")
-    void onClickReturnToDRG(final ClickEvent event) {
+    @EventHandler("returnToLink")
+    void onClickReturnToLink(final ClickEvent event) {
         presenter.exit();
     }
 
     @Override
     public void onResize() {
-        gridPanel.onResize();
+        gridPanelContainer.onResize();
+    }
+
+    @Override
+    public void setFocus() {
+        gridPanel.setFocus(true);
     }
 }
