@@ -17,7 +17,6 @@
 package org.kie.workbench.common.dmn.client.editors.expressions.types.function;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 import java.util.Optional;
 import java.util.function.Supplier;
@@ -28,55 +27,68 @@ import com.ait.lienzo.shared.core.types.EventPropagationMode;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.FunctionDefinition;
 import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
+import org.kie.workbench.common.dmn.api.property.dmn.QName;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.function.AddParameterCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.function.ClearExpressionTypeCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.function.RemoveParameterCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.function.SetKindCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.function.UpdateParameterNameCommand;
+import org.kie.workbench.common.dmn.client.commands.expressions.types.function.UpdateParameterTypeRefCommand;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
-import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.kindselector.HasKindSelectControl;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.kindselector.KindPopoverView;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.function.parameters.HasParametersControl;
-import org.kie.workbench.common.dmn.client.editors.expressions.types.function.parameters.ParametersEditorView;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.parameters.ParametersPopoverView;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
+import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
+import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.mvp.Command;
 
 public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGridData, FunctionUIModelMapper> implements HasListSelectorControl,
-                                                                                                                        HasParametersControl {
+                                                                                                                        HasParametersControl,
+                                                                                                                        HasKindSelectControl {
 
     private final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
     private final Supplier<ExpressionEditorDefinitions> supplementaryEditorDefinitionsSupplier;
-    private final ParametersEditorView.Presenter parametersEditor;
+
+    private final NameAndDataTypePopoverView.Presenter headerEditor;
+    private final ParametersPopoverView.Presenter parametersEditor;
+    private final KindPopoverView.Presenter kindEditor;
 
     public FunctionGrid(final GridCellTuple parent,
                         final Optional<String> nodeUUID,
                         final HasExpression hasExpression,
-                        final Optional<FunctionDefinition> expression,
                         final Optional<HasName> hasName,
                         final DMNGridPanel gridPanel,
                         final DMNGridLayer gridLayer,
@@ -84,36 +96,43 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                         final DefinitionUtils definitionUtils,
                         final SessionManager sessionManager,
                         final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                        final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                        final DefaultCanvasCommandFactory canvasCommandFactory,
                         final Event<ExpressionEditorChanged> editorSelectedEvent,
+                        final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                        final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                         final CellEditorControlsView.Presenter cellEditorControls,
                         final ListSelectorView.Presenter listSelector,
                         final TranslationService translationService,
                         final int nesting,
                         final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
                         final Supplier<ExpressionEditorDefinitions> supplementaryEditorDefinitionsSupplier,
-                        final ParametersEditorView.Presenter parametersEditor) {
+                        final NameAndDataTypePopoverView.Presenter headerEditor,
+                        final ParametersPopoverView.Presenter parametersEditor,
+                        final KindPopoverView.Presenter kindEditor) {
         super(parent,
               nodeUUID,
               hasExpression,
-              expression,
               hasName,
               gridPanel,
               gridLayer,
               gridData,
-              new FunctionGridRenderer(nesting > 0),
+              new FunctionGridRenderer(gridData),
               definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               cellEditorControls,
               listSelector,
               translationService,
               nesting);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
         this.supplementaryEditorDefinitionsSupplier = supplementaryEditorDefinitionsSupplier;
+        this.headerEditor = headerEditor;
         this.parametersEditor = parametersEditor;
+        this.kindEditor = kindEditor;
 
         setEventPropagationMode(EventPropagationMode.NO_ANCESTORS);
 
@@ -130,7 +149,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
     public FunctionUIModelMapper makeUiModelMapper() {
         return new FunctionUIModelMapper(this,
                                          this::getModel,
-                                         () -> expression,
+                                         getExpression(),
                                          expressionEditorDefinitionsSupplier,
                                          supplementaryEditorDefinitionsSupplier,
                                          listSelector,
@@ -139,16 +158,37 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
 
     @Override
     protected void initialiseUiColumns() {
-        final GridColumn expressionColumn = new ExpressionEditorColumn(gridLayer,
-                                                                       Arrays.asList(new FunctionColumnNameHeaderMetaData(() -> hasName.orElse(HasName.NOP).getName().getValue(),
-                                                                                                                          (s) -> hasName.orElse(HasName.NOP).getName().setValue(s),
-                                                                                                                          getHeaderHasNameTextBoxFactory()),
-                                                                                     new FunctionColumnParametersHeaderMetaData(expression::get,
-                                                                                                                                cellEditorControls,
-                                                                                                                                parametersEditor,
-                                                                                                                                this)),
-                                                                       this);
+        final List<GridColumn.HeaderMetaData> headerMetaData = new ArrayList<>();
+        if (nesting == 0) {
+            headerMetaData.add(new FunctionColumnNameHeaderMetaData(hasExpression,
+                                                                    hasName,
+                                                                    clearDisplayNameConsumer(true),
+                                                                    setDisplayNameConsumer(true),
+                                                                    setTypeRefConsumer(),
+                                                                    cellEditorControls,
+                                                                    headerEditor,
+                                                                    Optional.of(translationService.getTranslation(DMNEditorConstants.FunctionEditor_EditExpression))));
+        }
+        headerMetaData.add(new FunctionColumnParametersHeaderMetaData(getExpression(),
+                                                                      translationService,
+                                                                      cellEditorControls,
+                                                                      parametersEditor,
+                                                                      Optional.of(translationService.getTranslation(DMNEditorConstants.FunctionEditor_EditParametersTitle)),
+                                                                      this));
 
+        final FunctionKindRowColumn kindColumn = new FunctionKindRowColumn(getExpression(),
+                                                                           cellEditorControls,
+                                                                           kindEditor,
+                                                                           Optional.of(translationService.getTranslation(DMNEditorConstants.FunctionEditor_SelectFunctionKind)),
+                                                                           getAndSetInitialWidth(0, EmptyColumn.DEFAULT_WIDTH),
+                                                                           this);
+
+        final GridColumn expressionColumn = new FunctionColumn(gridLayer,
+                                                               headerMetaData,
+                                                               getAndSetInitialWidth(1, UndefinedExpressionColumn.DEFAULT_WIDTH),
+                                                               this);
+
+        model.appendColumn(kindColumn);
         model.appendColumn(expressionColumn);
 
         getRenderer().setColumnRenderConstraint((isSelectionLayer, gridColumn) -> !isSelectionLayer || gridColumn.equals(expressionColumn));
@@ -156,41 +196,18 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
 
     @Override
     protected void initialiseUiModel() {
-        expression.ifPresent(e -> {
-            model.appendRow(new DMNGridRow());
-            uiModelMapper.fromDMNModel(0, 0);
+        getExpression().get().ifPresent(e -> {
+            model.appendRow(new ExpressionEditorGridRow());
+            uiModelMapper.fromDMNModel(0, 1);
         });
     }
 
-    @Override
-    protected boolean isHeaderHidden() {
-        return false;
-    }
-
     @Override
     @SuppressWarnings("unused")
     public List<ListSelectorItem> getItems(final int uiRowIndex,
                                            final int uiColumnIndex) {
         final List<ListSelectorItem> items = new ArrayList<>();
-        final FunctionDefinition.Kind kind = KindUtilities.getKind(expression.get());
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.FunctionEditor_FEEL),
-                                             !FunctionDefinition.Kind.FEEL.equals(kind),
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> setKind(FunctionDefinition.Kind.FEEL));
-                                             }));
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.FunctionEditor_JAVA),
-                                             !FunctionDefinition.Kind.JAVA.equals(kind),
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> setKind(FunctionDefinition.Kind.JAVA));
-                                             }));
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.FunctionEditor_PMML),
-                                             !FunctionDefinition.Kind.PMML.equals(kind),
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> setKind(FunctionDefinition.Kind.PMML));
-                                             }));
+        final FunctionDefinition.Kind kind = KindUtilities.getKind(getExpression().get().get());
 
         //If cell editor is UndefinedExpressionGrid don't add extra items
         final GridCell<?> cell = model.getCell(uiRowIndex, uiColumnIndex);
@@ -203,11 +220,11 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
             return items;
         }
 
-        items.add(new ListSelectorDividerItem());
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ExpressionEditor_Clear),
                                              true,
                                              () -> {
                                                  cellEditorControls.hide();
+                                                 gridPanel.setFocus(true);
                                                  clearExpressionType();
                                              }));
 
@@ -223,13 +240,13 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
     @Override
     public List<InformationItem> getParameters() {
         final List<InformationItem> parameters = new ArrayList<>();
-        expression.ifPresent(e -> parameters.addAll(e.getFormalParameter()));
+        getExpression().get().ifPresent(e -> parameters.addAll(e.getFormalParameter()));
         return parameters;
     }
 
     @Override
     public void addParameter(final Command onSuccess) {
-        expression.ifPresent(e -> {
+        getExpression().get().ifPresent(e -> {
             final InformationItem parameter = new InformationItem();
             parameter.setName(new Name("p" + e.getFormalParameter().size()));
 
@@ -238,6 +255,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                                                                   parameter,
                                                                   () -> {
                                                                       gridLayer.batch();
+                                                                      gridPanel.setFocus(true);
                                                                       onSuccess.execute();
                                                                   }));
         });
@@ -246,12 +264,13 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
     @Override
     public void removeParameter(final InformationItem parameter,
                                 final Command onSuccess) {
-        expression.ifPresent(e -> {
+        getExpression().get().ifPresent(e -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new RemoveParameterCommand(e,
                                                                      parameter,
                                                                      () -> {
                                                                          gridLayer.batch();
+                                                                         gridPanel.setFocus(true);
                                                                          onSuccess.execute();
                                                                      }));
         });
@@ -260,7 +279,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
     @Override
     public void updateParameterName(final InformationItem parameter,
                                     final String name) {
-        expression.ifPresent(e -> {
+        getExpression().get().ifPresent(e -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new UpdateParameterNameCommand(parameter,
                                                                          name,
@@ -268,8 +287,19 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
         });
     }
 
+    @Override
+    public void updateParameterTypeRef(final InformationItem parameter,
+                                       final QName typeRef) {
+        getExpression().get().ifPresent(e -> {
+            sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                          new UpdateParameterTypeRefCommand(parameter,
+                                                                            typeRef,
+                                                                            gridLayer::batch));
+        });
+    }
+
     void setKind(final FunctionDefinition.Kind kind) {
-        expression.ifPresent(function -> {
+        getExpression().get().ifPresent(function -> {
             switch (kind) {
                 case FEEL:
                     doSetKind(kind,
@@ -293,51 +323,76 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                    final FunctionDefinition function,
                    final Optional<ExpressionEditorDefinition<Expression>> oDefinition) {
         oDefinition.ifPresent(definition -> {
-            final GridCellTuple expressionParent = new GridCellTuple(0,
-                                                                     0,
-                                                                     this);
+            final GridCellTuple parent = new GridCellTuple(0, 1, FunctionGrid.this);
             final Optional<Expression> expression = definition.getModelClass();
-            definition.enrich(nodeUUID, expression);
+            definition.enrich(nodeUUID, hasExpression, expression);
 
-            final Optional<BaseExpressionGrid> gridWidget = definition.getEditor(expressionParent,
-                                                                                 Optional.empty(),
-                                                                                 hasExpression,
-                                                                                 expression,
-                                                                                 hasName,
-                                                                                 nesting + 1);
-            doSetKind(kind,
-                      function,
-                      expression,
-                      gridWidget);
+            sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                          new SetKindCommand(parent,
+                                                             function,
+                                                             kind,
+                                                             expression,
+                                                             (editor) -> {
+                                                                 resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                 editor.ifPresent(BaseExpressionGrid::selectFirstCell);
+                                                             },
+                                                             () -> {
+                                                                 resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                 selectFirstCell();
+                                                             },
+                                                             () -> {
+                                                                 Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>> editor = Optional.empty();
+                                                                 editor = definition.getEditor(parent,
+                                                                                               Optional.empty(),
+                                                                                               getExpression().get().get(),
+                                                                                               hasName,
+                                                                                               nesting + 1);
+                                                                 return editor;
+                                                             }));
         });
     }
 
-    void doSetKind(final FunctionDefinition.Kind kind,
-                   final FunctionDefinition function,
-                   final Optional<Expression> expression,
-                   final Optional<BaseExpressionGrid> editor) {
-        final GridCellValueTuple gcv = new GridCellValueTuple<>(0,
-                                                                0,
-                                                                this,
-                                                                new ExpressionCellValue(editor));
-        sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
-                                      new SetKindCommand(gcv,
-                                                         function,
-                                                         kind,
-                                                         expression,
-                                                         () -> resizeBasedOnCellExpressionEditor(0, 0)));
-    }
-
     void clearExpressionType() {
-        expression.ifPresent(function -> {
+        getExpression().get().ifPresent(function -> {
             final GridCellTuple gc = new GridCellTuple(0,
-                                                       0,
+                                                       1,
                                                        this);
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new ClearExpressionTypeCommand(gc,
                                                                          function,
                                                                          uiModelMapper,
-                                                                         () -> resizeBasedOnCellExpressionEditor(0, 0)));
+                                                                         () -> {
+                                                                             resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                             selectExpressionEditorFirstCell(0, 1);
+                                                                         },
+                                                                         () -> {
+                                                                             resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                             selectExpressionEditorFirstCell(0, 1);
+                                                                         }));
         });
     }
-}
+
+    @Override
+    public void doAfterSelectionChange(final int uiRowIndex,
+                                       final int uiColumnIndex) {
+        selectExpressionEditorFirstCell(0, 1);
+    }
+
+    @Override
+    public void doAfterHeaderSelectionChange(final int uiHeaderRowIndex,
+                                             final int uiHeaderColumnIndex) {
+        if (nesting == 0 && uiHeaderRowIndex == 0) {
+            final DMNModelInstrumentedBase base = hasExpression.asDMNModelInstrumentedBase();
+            if (base instanceof DomainObject) {
+                fireDomainObjectSelectionEvent((DomainObject) base);
+                return;
+            }
+        }
+        super.doAfterHeaderSelectionChange(uiHeaderRowIndex, uiHeaderColumnIndex);
+    }
+
+    @Override
+    public void setFunctionKind(final FunctionDefinition.Kind kind) {
+        setKind(kind);
+    }
+}
\ No newline at end of file
