@@ -16,48 +16,54 @@
 
 package org.kie.workbench.common.dmn.client.editors.expressions.types.context;
 
+import java.util.Collections;
+import java.util.List;
 import java.util.Optional;
 
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
-import org.assertj.core.api.Assertions;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.mocks.MockHasDOMElementResourcesHeaderMetaData;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.BaseGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.mockito.Mock;
+import org.uberfire.ext.wires.core.grids.client.model.GridCell;
+import org.uberfire.ext.wires.core.grids.client.model.GridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
-import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
-import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.BaseGridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.columns.GridColumnRenderer;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.GridRenderer;
-import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
-import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.GridPinnedModeManager;
 import org.uberfire.mocks.EventSourceMock;
 
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class ExpressionEditorColumnTest {
@@ -66,12 +72,6 @@ public class ExpressionEditorColumnTest {
 
     private static final int PADDING = 10;
 
-    @Mock
-    private GridSelectionManager selectionManager;
-
-    @Mock
-    private GridPinnedModeManager pinnedModeManager;
-
     @Mock
     private GridRenderer renderer;
 
@@ -91,11 +91,17 @@ public class ExpressionEditorColumnTest {
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
     @Mock
-    private CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
+    private DefaultCanvasCommandFactory canvasCommandFactory;
 
     @Mock
     private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
 
+    @Mock
+    private EventSourceMock<RefreshFormPropertiesEvent> refreshFormPropertiesEvent;
+
+    @Mock
+    private EventSourceMock<DomainObjectSelectionEvent> domainObjectSelectionEvent;
+
     @Mock
     private CellEditorControlsView.Presenter cellEditorControls;
 
@@ -107,21 +113,44 @@ public class ExpressionEditorColumnTest {
 
     private BaseGridData gridData;
 
-    private GridWidget widget;
+    private BaseGrid<Expression> widget;
 
     private ExpressionEditorColumn column;
 
     @Before
     public void setUp() throws Exception {
         gridData = new BaseGridData();
-        widget = new BaseGridWidget(gridData, selectionManager, pinnedModeManager, renderer);
-        column = new ExpressionEditorColumn(gridLayer, new BaseHeaderMetaData("column header"), widget);
+        widget = new BaseGrid<Expression>(gridLayer,
+                                          gridData,
+                                          renderer,
+                                          sessionManager,
+                                          sessionCommandManager,
+                                          canvasCommandFactory,
+                                          refreshFormPropertiesEvent,
+                                          domainObjectSelectionEvent,
+                                          cellEditorControls,
+                                          translationService) {
+            @Override
+            public List<ListSelectorItem> getItems(final int uiRowIndex,
+                                                   final int uiColumnIndex) {
+                return Collections.emptyList();
+            }
+
+            @Override
+            public void onItemSelected(final ListSelectorItem item) {
+                //NOP for tests
+            }
+        };
+        column = new ExpressionEditorColumn(gridLayer,
+                                            new BaseHeaderMetaData("column header"),
+                                            ExpressionEditorColumn.DEFAULT_WIDTH,
+                                            widget);
     }
 
     @Test
     public void testMinimalWidthNoContent() throws Exception {
         gridData.appendColumn(column);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(DEFAULT_WIDTH);
+        assertThat(column.getMinimumWidth()).isEqualTo(DEFAULT_WIDTH);
     }
 
     /**
@@ -132,13 +161,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthOneCellInEachRow() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100d);
         mockCells(1, 0, 150);
         mockCells(2, 0, 125);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(150);
+        assertThat(column.getMinimumWidth()).isEqualTo(150);
     }
 
     /**
@@ -149,13 +178,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthTwoCellsSum() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100);
         mockCells(1, 0, 50, 60);
         mockCells(2, 0, 105);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(110);
+        assertThat(column.getMinimumWidth()).isEqualTo(110);
     }
 
     /**
@@ -166,13 +195,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthThreeCellsSum() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100);
         mockCells(1, 0, 50, 60);
         mockCells(2, 0, 50, 60, 10);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(120);
+        assertThat(column.getMinimumWidth()).isEqualTo(120);
     }
 
     /**
@@ -183,13 +212,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthDefaultWidth() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 99);
         mockCells(1, 0, 30, 30, 30);
         mockCells(2, 0, 49, 50);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(DEFAULT_WIDTH);
+        assertThat(column.getMinimumWidth()).isEqualTo(DEFAULT_WIDTH);
     }
 
     /**
@@ -200,13 +229,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthNoCellsInMiddle() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100);
         mockCells(1, 0);
         mockCells(2, 0, 50, 60);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(110);
+        assertThat(column.getMinimumWidth()).isEqualTo(110);
     }
 
     /**
@@ -217,13 +246,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthOneCellInEachRowWithPadding() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCellsWithPadding(0, 0, PADDING, 100);
         mockCellsWithPadding(1, 0, PADDING, 150);
         mockCellsWithPadding(2, 0, PADDING, 125);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(170);
+        assertThat(column.getMinimumWidth()).isEqualTo(170);
     }
 
     /**
@@ -234,13 +263,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthTwoCellsSumWithPadding() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCellsWithPadding(0, 0, PADDING, 100);
         mockCellsWithPadding(1, 0, PADDING, 50, 60);
         mockCellsWithPadding(2, 0, PADDING, 105);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(130);
+        assertThat(column.getMinimumWidth()).isEqualTo(130);
     }
 
     /**
@@ -251,13 +280,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthThreeCellsSumWithPadding() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCellsWithPadding(0, 0, PADDING, 100);
         mockCellsWithPadding(1, 0, PADDING, 50, 60);
         mockCellsWithPadding(2, 0, PADDING, 50, 60, 10);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(140);
+        assertThat(column.getMinimumWidth()).isEqualTo(140);
     }
 
     /**
@@ -268,13 +297,13 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthDefaultWidthWithPadding() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCellsWithPadding(0, 0, PADDING, 99);
         mockCellsWithPadding(1, 0, PADDING, 30, 30, 30);
         mockCellsWithPadding(2, 0, PADDING, 49, 50);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(119);
+        assertThat(column.getMinimumWidth()).isEqualTo(119);
     }
 
     /**
@@ -285,62 +314,88 @@ public class ExpressionEditorColumnTest {
     @Test
     public void testMinimalWidthNoCellsInMiddleWithPadding() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCellsWithPadding(0, 0, PADDING, 100);
         mockCellsWithPadding(1, 0, PADDING);
         mockCellsWithPadding(2, 0, PADDING, 50, 60);
-        Assertions.assertThat(column.getMinimumWidth()).isEqualTo(130);
+        assertThat(column.getMinimumWidth()).isEqualTo(130);
     }
 
     @Test
     public void testUpdateInternalWidth() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100);
         mockCells(1, 0, 110);
         mockCells(2, 0, 50, 60);
         column.setWidthInternal(200D);
-        Assertions.assertThat(getColumnWidth(0, 0, 0)).isEqualTo(200D);
-        Assertions.assertThat(getColumnWidth(1, 0, 0)).isEqualTo(200D);
-        Assertions.assertThat(getColumnWidth(2, 0, 0)).isEqualTo(50D);
-        Assertions.assertThat(getColumnWidth(2, 0, 1)).isEqualTo(150D);
+        assertThat(getColumnWidth(0, 0, 0)).isEqualTo(200D);
+        assertThat(getColumnWidth(1, 0, 0)).isEqualTo(200D);
+        assertThat(getColumnWidth(2, 0, 0)).isEqualTo(50D);
+        assertThat(getColumnWidth(2, 0, 1)).isEqualTo(150D);
     }
 
     @Test
     public void testUpdateInternalWidthNoCellsInMiddle() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100);
         mockCells(1, 0);
         mockCells(2, 0, 50, 60);
         column.setWidthInternal(200D);
-        Assertions.assertThat(getColumnWidth(0, 0, 0)).isEqualTo(200D);
-        Assertions.assertThat(getColumnWidth(2, 0, 0)).isEqualTo(50D);
-        Assertions.assertThat(getColumnWidth(2, 0, 1)).isEqualTo(150D);
+        assertThat(getColumnWidth(0, 0, 0)).isEqualTo(200D);
+        assertThat(getColumnWidth(2, 0, 0)).isEqualTo(50D);
+        assertThat(getColumnWidth(2, 0, 1)).isEqualTo(150D);
     }
 
     @Test
     public void testUpdateInternalWidthResizedToSmaller() throws Exception {
         gridData.appendColumn(column);
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
-        gridData.appendRow(new DMNGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
+        gridData.appendRow(new BaseGridRow());
         mockCells(0, 0, 100);
         mockCells(1, 0, 30, 30, 30);
         mockCells(2, 0, 50, 60);
         column.setWidthInternal(80D);
-        Assertions.assertThat(getColumnWidth(0, 0, 0)).isEqualTo(80D);
-        Assertions.assertThat(getColumnWidth(1, 0, 0)).isEqualTo(30D);
-        Assertions.assertThat(getColumnWidth(1, 0, 1)).isEqualTo(30D);
-        Assertions.assertThat(getColumnWidth(1, 0, 2)).isEqualTo(20D);
-        Assertions.assertThat(getColumnWidth(2, 0, 0)).isEqualTo(50D);
-        Assertions.assertThat(getColumnWidth(2, 0, 1)).isEqualTo(30D);
+        assertThat(getColumnWidth(0, 0, 0)).isEqualTo(80D);
+        assertThat(getColumnWidth(1, 0, 0)).isEqualTo(30D);
+        assertThat(getColumnWidth(1, 0, 1)).isEqualTo(30D);
+        assertThat(getColumnWidth(1, 0, 2)).isEqualTo(20D);
+        assertThat(getColumnWidth(2, 0, 0)).isEqualTo(50D);
+        assertThat(getColumnWidth(2, 0, 1)).isEqualTo(30D);
+    }
+
+    @Test
+    public void testEditNestedUndefinedExpressionGrid() {
+        final GridCell<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cell = mock(GridCell.class);
+        final GridCellValue<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cellValue = mock(GridCellValue.class);
+        final UndefinedExpressionGrid undefinedExpressionGrid = mock(UndefinedExpressionGrid.class);
+        when(cell.getValue()).thenReturn(cellValue);
+        when(cellValue.getValue()).thenReturn(Optional.of(undefinedExpressionGrid));
+
+        column.edit(cell, null, null);
+
+        verify(undefinedExpressionGrid).startEditingCell(0, 0);
+    }
+
+    @Test
+    public void testEditNestedNotUndefinedExpressionGrid() {
+        final GridCell<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cell = mock(GridCell.class);
+        final GridCellValue<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cellValue = mock(GridCellValue.class);
+        final ContextGrid contextGrid = mock(ContextGrid.class);
+        when(cell.getValue()).thenReturn(cellValue);
+        when(cellValue.getValue()).thenReturn(Optional.of(contextGrid));
+
+        column.edit(cell, null, null);
+
+        verify(contextGrid).selectFirstCell();
     }
 
     @Test
@@ -373,21 +428,19 @@ public class ExpressionEditorColumnTest {
     }
 
     @SuppressWarnings("unchecked")
-    private BaseExpressionGrid mockEditor(final double padding,
-                                          final double... widthOfCells) {
+    private BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper> mockEditor(final double padding,
+                                                                                                                 final double... widthOfCells) {
         final GridColumn.HeaderMetaData headerMetaData = mock(GridColumn.HeaderMetaData.class);
         final GridColumnRenderer gridColumnRenderer = mock(GridColumnRenderer.class);
         final BaseExpressionGrid gridWidget = mock(BaseExpressionGrid.class);
+        when(gridWidget.getExpression()).thenReturn(Optional::empty);
 
         final GridCellTuple parent = new GridCellTuple(0, 0, null);
-        final HasExpression hasExpression = mock(HasExpression.class);
-        final Optional<LiteralExpression> expression = Optional.of(mock(LiteralExpression.class));
         final Optional<HasName> hasName = Optional.of(mock(HasName.class));
 
         return new BaseExpressionGrid(parent,
                                       Optional.empty(),
-                                      hasExpression,
-                                      expression,
+                                      HasExpression.NOP,
                                       hasName,
                                       gridPanel,
                                       gridLayer,
@@ -398,6 +451,8 @@ public class ExpressionEditorColumnTest {
                                       sessionCommandManager,
                                       canvasCommandFactory,
                                       editorSelectedEvent,
+                                      refreshFormPropertiesEvent,
+                                      domainObjectSelectionEvent,
                                       cellEditorControls,
                                       listSelector,
                                       translationService,
@@ -410,7 +465,10 @@ public class ExpressionEditorColumnTest {
             @Override
             protected void initialiseUiColumns() {
                 for (double width : widthOfCells) {
-                    model.appendColumn(new DMNGridColumn<GridWidget, Object>(headerMetaData, gridColumnRenderer, gridWidget) {{
+                    model.appendColumn(new DMNGridColumn<BaseGrid<Expression>, Object>(headerMetaData,
+                                                                                       gridColumnRenderer,
+                                                                                       width,
+                                                                                       gridWidget) {{
                         setMinimumWidth(width);
                         setWidth(width);
                     }});
@@ -423,8 +481,14 @@ public class ExpressionEditorColumnTest {
             }
 
             @Override
-            protected boolean isHeaderHidden() {
-                return false;
+            public List<ListSelectorItem> getItems(final int uiRowIndex,
+                                                   final int uiColumnIndex) {
+                return Collections.emptyList();
+            }
+
+            @Override
+            public void onItemSelected(final ListSelectorItem item) {
+                //Nothing for this test
             }
 
             @Override
