@@ -173,6 +173,9 @@ public class FormEditorPresenterAbstractTest {
     @Mock
     protected ErrorMessageDisplayer errorMessageDisplayer;
 
+    @Mock
+    protected MenuItem downloadMenuItem;
+
     protected TestFieldManager fieldManager;
 
     protected List<Path> assetUsages = new ArrayList<>();
@@ -293,6 +296,11 @@ public class FormEditorPresenterAbstractTest {
                 copyPopUpPresenter = FormEditorPresenterAbstractTest.this.copyPopUpPresenter;
             }
 
+            @Override
+            protected MenuItem downloadMenuItem() {
+                return downloadMenuItem;
+            }
+
             @Override
             public void doLoadContent(FormModelerContent content) {
                 super.doLoadContent(content);
