@@ -39,7 +39,6 @@ import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.ext.widgets.core.client.editors.texteditor.TextResourceType;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnMayClose;
-import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.category.Others;
 import org.uberfire.workbench.model.menu.Menus;
@@ -99,6 +98,8 @@ public abstract class KieTextEditorPresenter
                                assetUpdateValidator);
         }
 
+        addDownloadMenuItem(fileMenuBuilder);
+
         fileMenuBuilder
                 .addNewTopLevelMenu(versionRecordManager.buildMenu())
                 .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
@@ -114,12 +115,6 @@ public abstract class KieTextEditorPresenter
         return view::getContent;
     }
 
-    @Override
-    protected Command onValidate() {
-        // not used
-        return null;
-    }
-
     @Override
     protected void loadContent() {
         defaultEditorService.call(getLoadSuccessCallback(),
@@ -170,8 +165,10 @@ public abstract class KieTextEditorPresenter
     }
 
     @OnClose
+    @Override
     public void onClose() {
         this.versionRecordManager.clear();
+        super.onClose();
     }
 
     @OnMayClose
