@@ -17,9 +17,12 @@
 package org.kie.workbench.common.screens.defaulteditor.client.editor;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import java.util.Optional;
+
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.WorkspaceProject;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -31,6 +34,7 @@ import org.mockito.Spy;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
+import org.uberfire.workbench.model.menu.MenuItem;
 
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.*;
@@ -52,25 +56,35 @@ public class GuvnorDefaultEditorPresenterTest {
     protected ProjectController projectController;
 
     @Mock
-    protected ProjectContext workbenchContext;
+    protected WorkspaceProjectContext workbenchContext;
+
+    @Mock
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    protected MenuItem alertsButtonMenuItem;
 
     protected GuvnorDefaultEditorPresenter presenter;
 
     @Before
     public void setup() {
-        presenter = new GuvnorDefaultEditorPresenter(mock(GuvnorDefaultEditorView.class)) {
+        doReturn(alertsButtonMenuItem).when(alertsButtonMenuItemBuilder).build();
+        presenter = spy(new GuvnorDefaultEditorPresenter(mock(GuvnorDefaultEditorView.class)) {
             {
                 fileMenuBuilder = GuvnorDefaultEditorPresenterTest.this.fileMenuBuilder;
                 projectController = GuvnorDefaultEditorPresenterTest.this.projectController;
                 workbenchContext = GuvnorDefaultEditorPresenterTest.this.workbenchContext;
                 versionRecordManager = GuvnorDefaultEditorPresenterTest.this.versionRecordManager;
+                alertsButtonMenuItemBuilder = GuvnorDefaultEditorPresenterTest.this.alertsButtonMenuItemBuilder;
             }
-        };
+        });
+
+        doNothing().when(presenter).addDownloadMenuItem(any());
     }
 
     @Test
     public void testMakeMenuBar() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
@@ -81,11 +95,13 @@ public class GuvnorDefaultEditorPresenterTest {
                                           any(AssetUpdateValidator.class));
         verify(fileMenuBuilder).addDelete(any(Path.class),
                                           any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
+        verify(presenter).addDownloadMenuItem(fileMenuBuilder);
     }
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
@@ -99,5 +115,7 @@ public class GuvnorDefaultEditorPresenterTest {
         verify(fileMenuBuilder,
                never()).addDelete(any(Path.class),
                                   any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
+        verify(presenter).addDownloadMenuItem(fileMenuBuilder);
     }
 }
