@@ -18,11 +18,14 @@ package org.kie.workbench.common.screens.library.client.screens.organizationalun
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
+import java.util.List;
 import javax.annotation.PostConstruct;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
-import org.guvnor.structure.client.security.OrganizationalUnitController;
+import org.guvnor.structure.contributors.Contributor;
+import org.guvnor.structure.contributors.ContributorType;
 import org.guvnor.structure.events.AfterCreateOrganizationalUnitEvent;
 import org.guvnor.structure.events.AfterEditOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
@@ -30,10 +33,12 @@ import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
 import org.guvnor.structure.repositories.Repository;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
+import org.kie.workbench.common.screens.library.client.util.LibraryPermissions;
 import org.uberfire.client.mvp.UberElement;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
 import org.uberfire.mvp.Command;
+import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 
 public class OrganizationalUnitPopUpPresenter {
@@ -41,9 +46,7 @@ public class OrganizationalUnitPopUpPresenter {
     public interface View extends UberElement<OrganizationalUnitPopUpPresenter>,
                                   HasBusyIndicator {
 
-        void showAddPopUp();
-
-        void showEditPopUp(OrganizationalUnit organizationalUnit);
+        void show();
 
         void hide();
 
@@ -53,16 +56,8 @@ public class OrganizationalUnitPopUpPresenter {
 
         String getName();
 
-        String getDefaultGroupId();
-
-        String getOwner();
-
         String getEmptyNameValidationMessage();
 
-        String getEmptyDefaultGroupIdValidationMessage();
-
-        String getInvalidDefaultGroupIdValidationMessage();
-
         String getDuplicatedOrganizationalUnitValidationMessage();
 
         String getSavingMessage();
@@ -82,7 +77,9 @@ public class OrganizationalUnitPopUpPresenter {
 
     private Event<NotificationEvent> notificationEvent;
 
-    private OrganizationalUnitController organizationalUnitController;
+    private LibraryPermissions libraryPermissions;
+
+    private SessionInfo sessionInfo;
 
     private OrganizationalUnit organizationalUnit;
 
@@ -92,13 +89,15 @@ public class OrganizationalUnitPopUpPresenter {
                                             final Event<AfterCreateOrganizationalUnitEvent> afterCreateOrganizationalUnitEvent,
                                             final Event<AfterEditOrganizationalUnitEvent> afterEditOrganizationalUnitEvent,
                                             final Event<NotificationEvent> notificationEvent,
-                                            final OrganizationalUnitController organizationalUnitController) {
+                                            final LibraryPermissions libraryPermissions,
+                                            final SessionInfo sessionInfo) {
         this.view = view;
         this.organizationalUnitService = organizationalUnitService;
         this.afterCreateOrganizationalUnitEvent = afterCreateOrganizationalUnitEvent;
         this.afterEditOrganizationalUnitEvent = afterEditOrganizationalUnitEvent;
         this.notificationEvent = notificationEvent;
-        this.organizationalUnitController = organizationalUnitController;
+        this.libraryPermissions = libraryPermissions;
+        this.sessionInfo = sessionInfo;
     }
 
     @PostConstruct
@@ -106,53 +105,22 @@ public class OrganizationalUnitPopUpPresenter {
         view.init(this);
     }
 
-    public void showAddPopUp() {
-        if (organizationalUnitController.canCreateOrgUnits()) {
+    public void show() {
+        if (libraryPermissions.userCanCreateOrganizationalUnit()) {
             view.clear();
-            view.showAddPopUp();
-        }
-    }
-
-    public void showEditPopUp(final OrganizationalUnit organizationalUnit) {
-        if (organizationalUnitController.canUpdateOrgUnit(organizationalUnit)) {
-            view.showEditPopUp(organizationalUnit);
-            this.organizationalUnit = organizationalUnit;
+            view.show();
         }
     }
 
     public void save() {
         final String name = view.getName();
-        final String defaultGroupId = view.getDefaultGroupId();
-        final String owner = view.getOwner();
+        final String defaultGroupId = "com." + view.getName().toLowerCase();
+        final String owner = sessionInfo.getIdentity().getIdentifier();
 
         view.showBusyIndicator(view.getSavingMessage());
-        validateFields(() -> {
-            if (organizationalUnit == null) {
-                saveCreation(name,
-                             defaultGroupId,
-                             owner);
-            } else {
-                saveEdition(name,
-                            defaultGroupId,
-                            owner);
-            }
-        });
-    }
-
-    void saveEdition(String name,
-                     String defaultGroupId,
-                     String owner) {
-        organizationalUnitService.call((OrganizationalUnit newOrganizationalUnit) -> {
-                                           afterEditOrganizationalUnitEvent.fire(new AfterEditOrganizationalUnitEvent(OrganizationalUnitPopUpPresenter.this.organizationalUnit,
-                                                                                                                      newOrganizationalUnit));
-                                           view.hideBusyIndicator();
-                                           notificationEvent.fire(new NotificationEvent(view.getSaveSuccessMessage(),
-                                                                                        NotificationEvent.NotificationType.SUCCESS));
-                                           view.hide();
-                                       },
-                                       new HasBusyIndicatorDefaultErrorCallback(view)).updateOrganizationalUnit(name,
-                                                                                                                owner,
-                                                                                                                defaultGroupId);
+        validateFields(() -> saveCreation(name,
+                                          defaultGroupId,
+                                          owner));
     }
 
     void saveCreation(final String name,
@@ -160,6 +128,7 @@ public class OrganizationalUnitPopUpPresenter {
                       final String owner) {
         final Command saveCommand = () -> {
             final Collection<Repository> repositories = new ArrayList<>();
+            final List<Contributor> contributors = Collections.singletonList(new Contributor(owner, ContributorType.OWNER));
 
             final RemoteCallback<OrganizationalUnit> successCallback = (OrganizationalUnit newOrganizationalUnit) -> {
                 afterCreateOrganizationalUnitEvent.fire(new AfterCreateOrganizationalUnitEvent(newOrganizationalUnit));
@@ -173,9 +142,9 @@ public class OrganizationalUnitPopUpPresenter {
 
             organizationalUnitService.call(successCallback,
                                            errorCallback).createOrganizationalUnit(name,
-                                                                                   owner,
                                                                                    defaultGroupId,
-                                                                                   repositories);
+                                                                                   repositories,
+                                                                                   contributors);
         };
 
         validateDuplicatedOrganizationalUnit(name,
@@ -190,17 +159,12 @@ public class OrganizationalUnitPopUpPresenter {
             return;
         }
 
-        final String defaultGroupId = view.getDefaultGroupId();
-        if (isEmpty(defaultGroupId)) {
-            view.hideBusyIndicator();
-            view.showError(view.getEmptyDefaultGroupIdValidationMessage());
-            return;
-        }
+        final String defaultGroupId = "com." + view.getName().toLowerCase();
 
         organizationalUnitService.call((Boolean valid) -> {
                                            if (!valid) {
                                                view.hideBusyIndicator();
-                                               view.showError(view.getInvalidDefaultGroupIdValidationMessage());
+                                               view.showError(view.getInvalidNameValidationMessage());
                                                return;
                                            }
 
