@@ -39,7 +39,8 @@ import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
-import org.kie.workbench.common.screens.projecteditor.util.NewWorkspaceProjectUtils;
+import org.kie.workbench.common.screens.projecteditor.client.util.KiePOMDefaultOptions;
+import org.kie.workbench.common.screens.projecteditor.client.wizard.POMBuilder;
 import org.kie.workbench.common.services.shared.validation.ValidationService;
 import org.kie.workbench.common.widgets.client.callbacks.CommandWithThrowableDrivenErrorCallback;
 import org.uberfire.client.mvp.UberElement;
@@ -47,6 +48,7 @@ import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.mvp.Command;
+import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 
@@ -67,6 +69,12 @@ public class AddProjectPopUpPresenter {
 
         void setDescription(String description);
 
+        void setGroupId(String groupId);
+
+        void setArtifactId(String artifactId);
+
+        void setVersion(String version);
+
         boolean isAdvancedOptionsSelected();
 
         void show();
@@ -96,6 +104,8 @@ public class AddProjectPopUpPresenter {
         String getEmptyVersionMessage();
 
         String getInvalidVersionMessage();
+
+        void setAddButtonEnabled(boolean enabled);
     }
 
     private Caller<LibraryService> libraryService;
@@ -121,6 +131,8 @@ public class AddProjectPopUpPresenter {
 
     LibraryInfo libraryInfo;
 
+    ParameterizedCommand<WorkspaceProject> successCallback;
+
     @Inject
     public AddProjectPopUpPresenter(final Caller<LibraryService> libraryService,
                                     final BusyIndicatorView busyIndicatorView,
@@ -156,12 +168,19 @@ public class AddProjectPopUpPresenter {
                 AddProjectPopUpPresenter.this.libraryInfo = libraryInfo;
             }
         }).getLibraryInfo(projectContext.getActiveOrganizationalUnit()
-                                        .orElseThrow(() -> new IllegalStateException("Cannot get library info without an active organizational unit.")));
+                                  .orElseThrow(() -> new IllegalStateException("Cannot get library info without an active organizational unit.")));
+    }
+
+    public void setSuccessCallback(ParameterizedCommand<WorkspaceProject> successCallback) {
+        this.successCallback = successCallback;
     }
 
     public void show() {
         libraryPreferences.load(loadedLibraryPreferences -> {
                                     view.setDescription(loadedLibraryPreferences.getProjectPreferences().getDescription());
+                                    view.setVersion(loadedLibraryPreferences.getProjectPreferences().getVersion());
+                                    view.setGroupId(projectContext.getActiveOrganizationalUnit().isPresent() ? projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId()
+                                                            : loadedLibraryPreferences.getOrganizationalUnitPreferences().getGroupId());
                                     view.show();
                                 },
                                 error -> {
@@ -173,7 +192,7 @@ public class AddProjectPopUpPresenter {
     }
 
     private void createProject(final DeploymentMode mode) {
-        view.showBusyIndicator(view.getSavingMessage());
+        beginProjectCreation();
 
         final String name = view.getName();
         final String description = view.getDescription();
@@ -186,31 +205,34 @@ public class AddProjectPopUpPresenter {
                        artifactId,
                        version,
                        () -> {
-                           final RemoteCallback<WorkspaceProject> successCallback = getSuccessCallback();
+                           final ParameterizedCommand<WorkspaceProject> successCallback = (project) -> {
+                               endProjectCreation();
+                               getSuccessCallback().execute(project);
+                           };
                            final ErrorCallback<?> errorCallback = getErrorCallback();
-                           if (view.isAdvancedOptionsSelected()) {
-
-                               final POM pom = new POM(new GAV(groupId,
-                                                               artifactId,
-                                                               version));
-                               pom.setName(name);
-                               pom.setDescription(description);
-                               libraryService.call(successCallback,
-                                                   errorCallback).createProject(projectContext.getActiveOrganizationalUnit()
-                                                                                              .orElseThrow(() -> new IllegalStateException("Cannot create new project without an active organizational unit.")),
-                                                                                pom,
-                                                                                mode);
-                           } else {
-                               libraryService.call(successCallback,
-                                                   errorCallback).createProject(name,
-                                                                                projectContext.getActiveOrganizationalUnit()
-                                                                                              .orElseThrow(() -> new IllegalStateException("Cannot create new project without an active organizational unit.")),
-                                                                                description,
-                                                                                mode);
-                           }
+                           final POM pom = setDefaultPOM(groupId,
+                                                         artifactId,
+                                                         version,
+                                                         name,
+                                                         description);
+                           libraryService.call((WorkspaceProject project) -> successCallback.execute(project),
+                                               errorCallback).createProject(projectContext.getActiveOrganizationalUnit()
+                                                                                    .orElseThrow(() -> new IllegalStateException("Cannot create new project without an active organizational unit.")),
+                                                                            pom,
+                                                                            mode);
                        });
     }
 
+    private void beginProjectCreation() {
+        view.setAddButtonEnabled(false);
+        view.showBusyIndicator(view.getSavingMessage());
+    }
+
+    private void endProjectCreation() {
+        view.setAddButtonEnabled(true);
+        view.hideBusyIndicator();
+    }
+
     private void validateFields(final String name,
                                 final String groupId,
                                 final String artifactId,
@@ -229,19 +251,18 @@ public class AddProjectPopUpPresenter {
     private void validateName(final String name,
                               final Command successCallback) {
         if (name == null || name.trim().isEmpty()) {
-            view.hideBusyIndicator();
+            endProjectCreation();
             view.showError(view.getEmptyNameMessage());
             return;
         }
 
         validationService.call((Boolean isValid) -> {
-            final String sanitizeProjectName = NewWorkspaceProjectUtils.sanitizeProjectName(name);
-            if (Boolean.TRUE.equals(isValid) && !sanitizeProjectName.isEmpty()) {
+            if (Boolean.TRUE.equals(isValid)) {
                 if (successCallback != null) {
                     successCallback.execute();
                 }
             } else {
-                view.hideBusyIndicator();
+                endProjectCreation();
                 view.showError(view.getInvalidNameMessage());
             }
         }).isProjectNameValid(name);
@@ -250,7 +271,7 @@ public class AddProjectPopUpPresenter {
     private void validateGroupId(final String groupId,
                                  final Command successCallback) {
         if (groupId == null || groupId.trim().isEmpty()) {
-            view.hideBusyIndicator();
+            endProjectCreation();
             view.showError(view.getEmptyGroupIdMessage());
             return;
         }
@@ -261,7 +282,7 @@ public class AddProjectPopUpPresenter {
                     successCallback.execute();
                 }
             } else {
-                view.hideBusyIndicator();
+                endProjectCreation();
                 view.showError(view.getInvalidGroupIdMessage());
             }
         }).validateGroupId(groupId);
@@ -270,7 +291,7 @@ public class AddProjectPopUpPresenter {
     private void validateArtifactId(final String artifactId,
                                     final Command successCallback) {
         if (artifactId == null || artifactId.trim().isEmpty()) {
-            view.hideBusyIndicator();
+            endProjectCreation();
             view.showError(view.getEmptyArtifactIdMessage());
             return;
         }
@@ -281,7 +302,7 @@ public class AddProjectPopUpPresenter {
                     successCallback.execute();
                 }
             } else {
-                view.hideBusyIndicator();
+                endProjectCreation();
                 view.showError(view.getInvalidArtifactIdMessage());
             }
         }).validateArtifactId(artifactId);
@@ -290,7 +311,7 @@ public class AddProjectPopUpPresenter {
     private void validateVersion(final String version,
                                  final Command successCallback) {
         if (version == null || version.trim().isEmpty()) {
-            view.hideBusyIndicator();
+            endProjectCreation();
             view.showError(view.getEmptyVersionMessage());
             return;
         }
@@ -301,13 +322,21 @@ public class AddProjectPopUpPresenter {
                     successCallback.execute();
                 }
             } else {
-                view.hideBusyIndicator();
+                endProjectCreation();
                 view.showError(view.getInvalidVersionMessage());
             }
         }).validateGAVVersion(version);
     }
 
-    private RemoteCallback<WorkspaceProject> getSuccessCallback() {
+    public ParameterizedCommand<WorkspaceProject> getSuccessCallback() {
+        if (successCallback != null) {
+            return successCallback;
+        } else {
+            return getProjectCreationSuccessCallback();
+        }
+    }
+
+    public ParameterizedCommand<WorkspaceProject> getProjectCreationSuccessCallback() {
         return project -> {
             newProjectEvent.fire(new NewProjectEvent(project));
             view.hide();
@@ -322,7 +351,7 @@ public class AddProjectPopUpPresenter {
             put(GAVAlreadyExistsException.class,
                 parameter -> {
                     GAVAlreadyExistsException exception = (GAVAlreadyExistsException) parameter;
-                    view.hideBusyIndicator();
+                    endProjectCreation();
                     conflictingRepositoriesPopup.setContent(exception.getGAV(),
                                                             ((GAVAlreadyExistsException) parameter).getRepositories(),
                                                             () -> {
@@ -333,7 +362,7 @@ public class AddProjectPopUpPresenter {
                 });
             put(FileAlreadyExistsException.class,
                 parameter -> {
-                    view.hideBusyIndicator();
+                    endProjectCreation();
                     view.showError(view.getDuplicatedProjectMessage());
                 });
         }};
@@ -365,4 +394,29 @@ public class AddProjectPopUpPresenter {
     public void cancel() {
         view.hide();
     }
+
+    public void restoreDefaultAdvancedOptions() {
+        libraryPreferences.load(loadedLibraryPreferences -> {
+                                    view.setDescription(loadedLibraryPreferences.getProjectPreferences().getDescription());
+                                    view.setVersion(loadedLibraryPreferences.getProjectPreferences().getVersion());
+                                    view.setGroupId(projectContext.getActiveOrganizationalUnit().isPresent() ? projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId()
+                                                            : loadedLibraryPreferences.getOrganizationalUnitPreferences().getGroupId());
+                                },
+                                error -> {
+                                });
+    }
+
+    private POM setDefaultPOM(String groupId, String artifactId, String version, String name, String description) {
+        final POM pom = new POM(new GAV(groupId,
+                                        artifactId,
+                                        version));
+        pom.setName(name);
+        pom.setDescription(description);
+
+        POMBuilder pomBuilder = new POMBuilder(pom);
+        KiePOMDefaultOptions pomDefaultOptions = new KiePOMDefaultOptions();
+        pomBuilder.setBuildPlugins(pomDefaultOptions.getBuildPlugins());
+
+        return pomBuilder.build();
+    }
 }
