@@ -33,7 +33,6 @@ import com.google.gwt.user.client.Window;
 import org.ext.uberfire.social.activities.model.ExtendedTypes;
 import org.ext.uberfire.social.activities.model.SocialFileSelectedEvent;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
-import org.guvnor.common.services.project.client.preferences.ProjectScopedResolutionStrategySupplier;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeHandler;
 import org.guvnor.common.services.project.model.Package;
@@ -41,60 +40,60 @@ import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.common.services.project.social.ModuleEventType;
 import org.guvnor.messageconsole.client.console.MessageConsoleScreen;
+import org.guvnor.structure.events.AfterDeleteOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
-import org.guvnor.structure.organizationalunit.RemoveOrganizationalUnitEvent;
+import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
+import org.guvnor.structure.repositories.RepositoryService;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.jboss.errai.security.shared.api.identity.User;
 import org.jboss.errai.security.shared.exception.UnauthorizedException;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.soup.commons.validation.PortablePreconditions;
-import org.kie.workbench.common.screens.examples.model.ExampleProject;
+import org.kie.workbench.common.screens.examples.model.ImportProject;
 import org.kie.workbench.common.screens.explorer.client.utils.Utils;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectAssetListUpdated;
 import org.kie.workbench.common.screens.library.api.Remote;
 import org.kie.workbench.common.screens.library.api.Routed;
+import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
-import org.kie.workbench.common.screens.library.client.events.WorkbenchProjectMetricsEvent;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
 import org.kie.workbench.common.screens.library.client.resources.i18n.LibraryConstants;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportProjectsSetupEvent;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportRepositoryPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.Source;
 import org.kie.workbench.common.screens.library.client.screens.project.close.CloseUnsavedProjectAssetsPopUpPresenter;
-import org.kie.workbench.common.screens.library.client.widgets.library.LibraryToolbarPresenter;
+import org.kie.workbench.common.screens.library.client.util.breadcrumb.LibraryBreadcrumbs;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.widgets.client.handlers.NewResourceSuccessEvent;
-import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.VFSService;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
-import org.uberfire.client.workbench.events.PlaceMaximizedEvent;
-import org.uberfire.client.workbench.events.PlaceMinimizedEvent;
 import org.uberfire.ext.editor.commons.client.event.ConcurrentDeleteAcceptedEvent;
 import org.uberfire.ext.editor.commons.client.event.ConcurrentRenameAcceptedEvent;
 import org.uberfire.ext.preferences.client.central.screen.PreferencesRootScreen;
-import org.uberfire.ext.preferences.client.event.PreferencesCentralInitializationEvent;
 import org.uberfire.ext.preferences.client.event.PreferencesCentralSaveEvent;
 import org.uberfire.ext.preferences.client.event.PreferencesCentralUndoChangesEvent;
 import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
+import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
+import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
-import org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo;
+import org.uberfire.rpc.SessionInfo;
+import org.uberfire.spaces.Space;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.events.ResourceDeletedEvent;
 import org.uberfire.workbench.model.impl.PartDefinitionImpl;
 
-import static org.kie.workbench.common.screens.library.client.screens.importrepository.Source.Kind.EXTERNAL;
-
 @ApplicationScoped
 public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
@@ -131,12 +130,8 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     private TranslationService ts;
 
-    private Event<WorkbenchProjectMetricsEvent> projectMetricsEvent;
-
     private Event<AssetDetailEvent> assetDetailEvent;
 
-    private ResourceUtils resourceUtils;
-
     private Caller<LibraryService> libraryService;
 
     private Caller<WorkspaceProjectService> projectService;
@@ -149,10 +144,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     private WorkspaceProjectContext projectContext;
 
-    private LibraryToolbarPresenter libraryToolbar;
-
-    private AuthoringWorkbenchDocks docks;
-
     private Event<WorkspaceProjectContextChangeEvent> projectContextChangeEvent;
 
     private Event<NotificationEvent> notificationEvent;
@@ -161,10 +152,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     private Caller<VFSService> vfsService;
 
-    private ProjectScopedResolutionStrategySupplier projectScopedResolutionStrategySupplier;
-
-    private Event<PreferencesCentralInitializationEvent> preferencesCentralInitializationEvent;
-
     private ManagedInstance<ImportRepositoryPopUpPresenter> importRepositoryPopUpPresenters;
 
     private Event<ProjectAssetListUpdated> assetListUpdatedEvent;
@@ -173,11 +160,13 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     private Event<ImportProjectsSetupEvent> importProjectsSetupEvent;
 
-    private boolean docksReady = false;
+    private LibraryBreadcrumbs libraryBreadcrumbs;
 
-    private boolean docksHidden = true;
+    private SessionInfo sessionInfo;
 
-    private boolean editorMaximized = false;
+    private LibraryInternalPreferences libraryInternalPreferences;
+
+    private Caller<RepositoryService> repositoryService;
 
     private boolean closingLibraryPlaces = false;
 
@@ -187,56 +176,51 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     @Inject
     public LibraryPlaces(final UberfireBreadcrumbs breadcrumbs,
                          final TranslationService ts,
-                         final Event<WorkbenchProjectMetricsEvent> projectMetricsEvent,
                          final Event<AssetDetailEvent> assetDetailEvent,
-                         final ResourceUtils resourceUtils,
                          final Caller<LibraryService> libraryService,
                          final Caller<WorkspaceProjectService> projectService,
                          final Caller<KieModuleService> moduleService,
                          final PlaceManager placeManager,
                          final WorkspaceProjectContext projectContext,
-                         final LibraryToolbarPresenter libraryToolbar,
-                         final AuthoringWorkbenchDocks docks,
                          final Event<WorkspaceProjectContextChangeEvent> projectContextChangeEvent,
                          final Event<NotificationEvent> notificationEvent,
                          final TranslationUtils translationUtils,
                          final Caller<VFSService> vfsService,
-                         final ProjectScopedResolutionStrategySupplier projectScopedResolutionStrategySupplier,
-                         final Event<PreferencesCentralInitializationEvent> preferencesCentralInitializationEvent,
                          final ManagedInstance<ImportRepositoryPopUpPresenter> importRepositoryPopUpPresenters,
                          final @Routed Event<ProjectAssetListUpdated> assetListUpdatedEvent,
                          final CloseUnsavedProjectAssetsPopUpPresenter closeUnsavedProjectAssetsPopUpPresenter,
-                         final @Source(EXTERNAL) Event<ImportProjectsSetupEvent> importProjectsSetupEvent) {
+                         final @Source(Source.Kind.EXTERNAL) Event<ImportProjectsSetupEvent> importProjectsSetupEvent,
+                         final LibraryBreadcrumbs libraryBreadcrumbs,
+                         final SessionInfo sessionInfo,
+                         final LibraryInternalPreferences libraryInternalPreferences,
+                         final Caller<RepositoryService> repositoryService) {
         this.breadcrumbs = breadcrumbs;
         this.ts = ts;
-        this.projectMetricsEvent = projectMetricsEvent;
         this.assetDetailEvent = assetDetailEvent;
-        this.resourceUtils = resourceUtils;
         this.libraryService = libraryService;
         this.projectService = projectService;
         this.moduleService = moduleService;
         this.placeManager = placeManager;
         this.projectContext = projectContext;
-        this.libraryToolbar = libraryToolbar;
-        this.docks = docks;
         this.projectContextChangeEvent = projectContextChangeEvent;
         this.notificationEvent = notificationEvent;
         this.translationUtils = translationUtils;
         this.vfsService = vfsService;
-        this.projectScopedResolutionStrategySupplier = projectScopedResolutionStrategySupplier;
-        this.preferencesCentralInitializationEvent = preferencesCentralInitializationEvent;
         this.importRepositoryPopUpPresenters = importRepositoryPopUpPresenters;
         this.assetListUpdatedEvent = assetListUpdatedEvent;
         this.closeUnsavedProjectAssetsPopUpPresenter = closeUnsavedProjectAssetsPopUpPresenter;
         this.importProjectsSetupEvent = importProjectsSetupEvent;
+        this.libraryBreadcrumbs = libraryBreadcrumbs;
+        this.sessionInfo = sessionInfo;
+        this.libraryInternalPreferences = libraryInternalPreferences;
+        this.repositoryService = repositoryService;
     }
 
     @PostConstruct
     public void setup() {
-        projectContext.addChangeHandler(this);
+        libraryBreadcrumbs.init(this);
 
-        breadcrumbs.addToolbar(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                               libraryToolbar.getView().getElement());
+        projectContext.addChangeHandler(this);
 
         placeManager.registerPerspectiveCloseChain(LIBRARY_PERSPECTIVE,
                                                    (chain, place) -> {
@@ -254,33 +238,20 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
             final PlaceRequest place = placeGainFocusEvent.getPlace();
 
             if (place instanceof PathPlaceRequest) {
-                final PathPlaceRequest pathPlaceRequest = (PathPlaceRequest) place;
-                setupLibraryBreadCrumbsForAsset(pathPlaceRequest.getPath());
-                showDocks();
+                libraryBreadcrumbs.setupForAsset(getActiveWorkspace(),
+                                                 ((PathPlaceRequest) place).getPath());
             } else if (!place.getIdentifier().equals(ALERTS) && isLibraryPlace(place)) {
-                hideDocks();
-                if (place.getIdentifier().equals(PROJECT_SETTINGS)) {
-                    setupLibraryBreadCrumbsForAsset(null);
-                } else if (projectContext.getActiveWorkspaceProject().isPresent()
+                if (projectContext.getActiveWorkspaceProject().isPresent()
                         && place.getIdentifier().equals(LibraryPlaces.PROJECT_SCREEN)) {
-                    setupLibraryBreadCrumbs();
-                } else if (place.getIdentifier().equals(LibraryPlaces.LIBRARY_SCREEN)) {
-                    setupLibraryBreadCrumbsWithoutProject();
+                    libraryBreadcrumbs.setupForProject(getActiveWorkspace());
+                } else if (projectContext.getActiveOrganizationalUnit().isPresent()
+                        && place.getIdentifier().equals(LibraryPlaces.LIBRARY_SCREEN)) {
+                    libraryBreadcrumbs.setupForSpace(getActiveSpace());
                 }
             }
         }
     }
 
-    public void showDocksWhenMinimizingEditor(@Observes PlaceMinimizedEvent placeMinimizedEvent) {
-        editorMaximized = false;
-        showDocks();
-    }
-
-    public void hideDocksWhenMaximizingEditor(@Observes PlaceMaximizedEvent placeMaximizedEvent) {
-        editorMaximized = true;
-        hideDocks();
-    }
-
     /*
      * Re-reroutes this event for project screen. If we tried to observe this directly from the project screen,
      * there are timing issues involved with subscribing to the event.
@@ -289,25 +260,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         assetListUpdatedEvent.fire(event);
     }
 
-    public void hideDocks() {
-        if (!docksHidden) {
-            docks.hide();
-            docksHidden = true;
-        }
-    }
-
-    public void showDocks() {
-        if (docksHidden && !editorMaximized) {
-            if (!docksReady) {
-                docks.setup(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                            new DefaultPlaceRequest(PROJECT_EXPLORER));
-                docksReady = true;
-            }
-            docks.show();
-            docksHidden = false;
-        }
-    }
-
     private boolean isLibraryPlace(final PlaceRequest place) {
         return LIBRARY_PLACES.contains(place.getIdentifier());
     }
@@ -325,23 +277,31 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         if (isLibraryPerspectiveOpen()) {
             final ObservablePath path = concurrentRenameAcceptedEvent.getPath();
             goToAsset(path);
-            setupLibraryBreadCrumbsForAsset(path);
+            libraryBreadcrumbs.setupForAsset(getActiveWorkspace(),
+                                             path);
         }
     }
 
     public void onProjectDeleted(@Observes final RepositoryRemovedEvent repositoryRemovedEvent) {
         if (isLibraryPerspectiveOpen() && isRepoForActiveProject(repositoryRemovedEvent)) {
-            closeAllPlaces();
             WorkspaceProjectContextChangeEvent contextChangeEvent = projectContext.getActiveOrganizationalUnit()
                     .map(ou -> new WorkspaceProjectContextChangeEvent(ou))
                     .orElseGet(() -> new WorkspaceProjectContextChangeEvent());
             projectContextChangeEvent.fire(contextChangeEvent);
+            closeAllPlaces();
             goToLibrary();
             notificationEvent.fire(new NotificationEvent(ts.getTranslation(LibraryConstants.ProjectDeleted),
                                                          NotificationEvent.NotificationType.DEFAULT));
         }
     }
 
+    public void deleteProject(final WorkspaceProject project,
+                              final HasBusyIndicator view) {
+        repositoryService.call(v -> view.hideBusyIndicator(),
+                               new HasBusyIndicatorDefaultErrorCallback(view)).removeRepository(project.getSpace(),
+                                                                                                project.getRepository().getAlias());
+    }
+
     private boolean isRepoForActiveProject(RepositoryRemovedEvent repositoryRemovedEvent) {
         return projectContext.getActiveWorkspaceProject()
                 .filter(project -> {
@@ -352,13 +312,11 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                 .isPresent();
     }
 
-    public void onOrganizationalUnitRemoved(@Observes final RemoveOrganizationalUnitEvent removedOrganizationalUnitEvent) {
+    public void onOrganizationalUnitRemoved(@Observes final AfterDeleteOrganizationalUnitEvent removedOrganizationalUnitEvent) {
         if (isLibraryPerspectiveOpen()) {
             projectContext.getActiveOrganizationalUnit()
                     .filter(active -> active.equals(removedOrganizationalUnitEvent.getOrganizationalUnit()))
-                    .ifPresent(active -> {
-                        projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent());
-                    });
+                    .ifPresent(active -> this.goToOrganizationalUnits());
         }
     }
 
@@ -366,13 +324,11 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         goToAsset(assetDetails.getPath());
     }
 
-    public void setUpBranches() {
-        libraryToolbar.setUpBranches();
-    }
-
     private boolean isLibraryPerspectiveOpen() {
-        return placeManager.getStatus(LIBRARY_PERSPECTIVE).equals(PlaceStatus.OPEN)
-                || placeManager.getStatus(getLibraryPlaceRequestWithoutRefresh()).equals(PlaceStatus.OPEN);
+        final PlaceStatus statusPerspective = placeManager.getStatus(LIBRARY_PERSPECTIVE);
+        final PlaceStatus statusPerspectiveWithoutRefresh = placeManager.getStatus(getLibraryPlaceRequestWithoutRefresh());
+        return statusPerspective.equals(PlaceStatus.OPEN)
+                || statusPerspectiveWithoutRefresh.equals(PlaceStatus.OPEN);
     }
 
     public void onPreferencesSave(@Observes PreferencesCentralSaveEvent event) {
@@ -454,123 +410,26 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         return ModuleEventType.NEW_MODULE.name().equals(eventType);
     }
 
-    public void setupLibraryBreadCrumbs() {
-        setupLibraryBreadCrumbs(projectContext.getActiveWorkspaceProject().orElse(null));
-    }
-
-    public void setupLibraryBreadCrumbsWithoutProject() {
-        setupLibraryBreadCrumbs(null);
-    }
-
-    public void setupLibraryBreadCrumbs(final WorkspaceProject project) {
-        breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  translationUtils.getOrganizationalUnitAliasInPlural(),
-                                  () -> goToOrganizationalUnits(),
-                                  false);
-        projectContext.getActiveOrganizationalUnit()
-                .ifPresent(ou -> {
-                    breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                              ou.getName(),
-                                              () -> goToLibrary(),
-                                              false);
-                });
-
-        if (project != null) {
-            breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                      project.getName(),
-                                      () -> goToProject(),
-                                      false);
-        }
-
-        libraryToolbar.setUpBranches();
-    }
-
-    public void setupLibraryBreadCrumbsForTrySamples() {
-        breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  translationUtils.getOrganizationalUnitAliasInPlural(),
-                                  () -> goToOrganizationalUnits(),
-                                  false);
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  projectContext.getActiveOrganizationalUnit()
-                                          .orElseThrow(() -> new IllegalStateException("Cannot create library breadcrumb without active space."))
-                                          .getName(),
-                                  () -> goToLibrary(),
-                                  false);
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  ts.getTranslation(LibraryConstants.TrySamples),
-                                  () -> goToTrySamples(),
-                                  false);
-    }
-
-    public void setupLibraryBreadCrumbsForProjectMetrics() {
-        setupLibraryBreadCrumbs();
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  translationUtils.getProjectMetrics(),
-                                  () -> goToProjectMetrics(),
-                                  false);
-    }
-
-    public void setupLibraryBreadCrumbsForOrgUnitsMetrics() {
-        setupLibraryBreadCrumbs();
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  translationUtils.getOrgUnitsMetrics(),
-                                  () -> goToOrgUnitsMetrics(),
-                                  false);
-    }
-
-    public void setupLibraryBreadCrumbsForAsset(final Path path) {
-        setupLibraryBreadCrumbs();
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  getAssetName(path),
-                                  () -> goToAsset(path),
-                                  false);
-    }
-
-    private String getAssetName(final Path path) {
-        if (path != null) {
-            return resourceUtils.getBaseFileName(path);
-        } else {
-            return ts.format(LibraryConstants.Settings);
-        }
-    }
-
-    public void setupLibraryBreadCrumbsForPreferences() {
-        setupLibraryBreadCrumbs();
-        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
-                                  ts.getTranslation(LibraryConstants.Preferences),
-                                  () -> goToPreferences(),
-                                  false);
-    }
-
     public void refresh(final Command callback) {
-        editorMaximized = false;
         breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
-        translationUtils.refresh(() -> {
-            libraryToolbar.init(() -> {
-                if (callback != null) {
-
-                    callback.execute();
-                }
-            });
-        });
+        translationUtils.refresh(callback::execute);
     }
 
     public void goToOrganizationalUnits() {
-        closeAllPlacesOrNothing(() -> {
-            PortablePreconditions.checkNotNull("libraryPerspective.closeAllPlacesOrNothing",
-                                               libraryPerspective);
+        closeAllPlacesOrNothing(this::goToSpaces);
+    }
 
-            projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent());
+    private void goToSpaces() {
+        PortablePreconditions.checkNotNull("libraryPerspective.closeAllPlacesOrNothing",
+                                           libraryPerspective);
+        projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent());
 
-            final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.ORGANIZATIONAL_UNITS_SCREEN);
-            final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
-            part.setSelectable(false);
-            placeManager.goTo(part,
-                              libraryPerspective.getRootPanel());
-            setupLibraryBreadCrumbs();
-        });
+        final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.ORGANIZATIONAL_UNITS_SCREEN);
+        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
+        part.setSelectable(false);
+        placeManager.goTo(part,
+                          libraryPerspective.getRootPanel());
+        libraryBreadcrumbs.setupForSpacesScreen();
     }
 
     public void goToLibrary() {
@@ -613,25 +472,49 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         placeManager.goTo(part,
                           libraryPerspective.getRootPanel());
 
-        setupLibraryBreadCrumbsWithoutProject();
-
-        hideDocks();
+        libraryBreadcrumbs.setupForSpace(activeOu);
     }
 
     public void goToProject(final WorkspaceProject project) {
         if (projectContext.getActiveWorkspaceProject()
                 .map(activeProject -> !activeProject.equals(project))
                 .orElse(true)) {
-            closeAllPlacesOrNothing(() -> {
-                projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(project,
-                                                                                      project.getMainModule()));
-                goToProject();
-            });
+            libraryInternalPreferences.load(loadedLibraryInternalPreferences -> {
+                                                closeAllPlacesOrNothing(() -> {
+                                                    projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(project,
+                                                                                                                          project.getMainModule()));
+                                                    goToProject(project,
+                                                                loadedLibraryInternalPreferences.getLastBranchOpened(project).orElse(project.getBranch()));
+                                                });
+                                            },
+                                            error -> {
+                                            });
         } else {
             goToProject();
         }
     }
 
+    public void goToProject(final WorkspaceProject project,
+                            final Branch branch) {
+        libraryInternalPreferences.load(loadedLibraryInternalPreferences -> {
+                                            final Optional<Branch> lastBranchOpened = loadedLibraryInternalPreferences.getLastBranchOpened(project);
+                                            final Command goToProjectCommand = () -> projectService.call((RemoteCallback<WorkspaceProject>) this::goToProject).resolveProject(project.getSpace(),
+                                                                                                                                                                              branch);
+
+                                            if (!lastBranchOpened.isPresent() || !lastBranchOpened.get().equals(branch)) {
+                                                loadedLibraryInternalPreferences.setLastBranchOpened(project,
+                                                                                                     branch);
+                                                loadedLibraryInternalPreferences.save(goToProjectCommand,
+                                                                                      error -> {
+                                                                                      });
+                                            } else {
+                                                goToProjectCommand.execute();
+                                            }
+                                        },
+                                        error -> {
+                                        });
+    }
+
     void goToProject() {
         goToProject(() -> {
             // do nothing.
@@ -639,8 +522,8 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     }
 
     private void goToProject(final Command callback) {
-        setupLibraryBreadCrumbs(projectContext.getActiveWorkspaceProject()
-                                        .orElseThrow(() -> new IllegalStateException("Cannot go to project when no project is active.")));
+        libraryBreadcrumbs.setupForProject(projectContext.getActiveWorkspaceProject()
+                                                   .orElseThrow(() -> new IllegalStateException("Cannot go to project when no project is active.")));
 
         final PartDefinitionImpl part = new PartDefinitionImpl(new DefaultPlaceRequest(LibraryPlaces.PROJECT_SCREEN));
         part.setSelectable(false);
@@ -653,26 +536,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         }
     }
 
-    public void goToOrgUnitsMetrics() {
-        final PlaceRequest metricsScreen = new DefaultPlaceRequest(LibraryPlaces.ORG_UNITS_METRICS_SCREEN);
-        final PartDefinitionImpl part = new PartDefinitionImpl(metricsScreen);
-        part.setSelectable(false);
-        placeManager.goTo(part,
-                          libraryPerspective.getRootPanel());
-        setupLibraryBreadCrumbsForOrgUnitsMetrics();
-    }
-
-    public void goToProjectMetrics() {
-        final PlaceRequest metricsScreen = new DefaultPlaceRequest(LibraryPlaces.PROJECT_METRICS_SCREEN);
-        final PartDefinitionImpl part = new PartDefinitionImpl(metricsScreen);
-        part.setSelectable(false);
-        placeManager.goTo(part,
-                          libraryPerspective.getRootPanel());
-        setupLibraryBreadCrumbsForProjectMetrics();
-        projectMetricsEvent.fire(new WorkbenchProjectMetricsEvent(projectContext.getActiveWorkspaceProject()
-                                                                          .orElseThrow(() -> new IllegalStateException("Cannot fire event for project metrics without an active project."))));
-    }
-
     public void goToAsset(final Path path) {
 
         moduleService.call((RemoteCallback<Package>) response -> {
@@ -686,7 +549,8 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
             if (path != null) {
                 final ObservablePath observablePath = ((PathPlaceRequest) placeRequest).getPath();
-                observablePath.onRename(() -> setupLibraryBreadCrumbsForAsset(observablePath));
+                observablePath.onRename(() -> libraryBreadcrumbs.setupForAsset(getActiveWorkspace(),
+                                                                               observablePath));
             }
         }).resolvePackage(path);
     }
@@ -707,7 +571,7 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
             placeManager.goTo(part,
                               libraryPerspective.getRootPanel());
-            setupLibraryBreadCrumbsForTrySamples();
+            libraryBreadcrumbs.setupForTrySamples(getActiveSpace());
         });
     }
 
@@ -716,7 +580,7 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         importRepositoryPopUpPresenter.show();
     }
 
-    public void goToExternalImportPresenter(final Set<ExampleProject> projects) {
+    public void goToExternalImportPresenter(final Set<ImportProject> projects) {
         closeAllPlacesOrNothing(() -> {
             // TODO add title
             final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.IMPORT_PROJECTS_SCREEN);
@@ -746,25 +610,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                                   () -> goToImportRepositoryPopUp());
     }
 
-    public void goToPreferences() {
-
-        final PreferenceScopeResolutionStrategyInfo customScopeResolutionStrategy = projectScopedResolutionStrategySupplier.get();
-
-        final PreferencesCentralInitializationEvent initEvent = new PreferencesCentralInitializationEvent("ProjectPreferences",
-                                                                                                          customScopeResolutionStrategy,
-                                                                                                          null);
-
-        final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(PreferencesRootScreen.IDENTIFIER);
-        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
-        part.setSelectable(false);
-
-        placeManager.goTo(part,
-                          libraryPerspective.getRootPanel());
-
-        preferencesCentralInitializationEvent.fire(initEvent);
-        setupLibraryBreadCrumbsForPreferences();
-    }
-
     PlaceRequest generatePlaceRequest(final Path path) {
         if (path == null) {
             return new DefaultPlaceRequest(PROJECT_SETTINGS);
@@ -789,12 +634,14 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         final List<PlaceRequest> uncloseablePlaces = placeManager.getUncloseablePlaces();
         if (uncloseablePlaces != null && uncloseablePlaces.isEmpty()) {
             placeManager.closeAllPlaces();
+            closingLibraryPlaces = false;
             if (successCallback != null) {
                 successCallback.execute();
             }
         } else {
             final Command newSuccessCallback = () -> {
                 placeManager.forceCloseAllPlaces();
+                closingLibraryPlaces = false;
                 if (successCallback != null) {
                     successCallback.execute();
                 }
@@ -802,11 +649,9 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
             closeUnsavedProjectAssetsPopUpPresenter.show(getActiveWorkspace(),
                                                          uncloseablePlaces,
-                                                         Optional.of(newSuccessCallback),
-                                                         Optional.of(() -> placeManager.goTo(uncloseablePlaces.get(0))));
+                                                         newSuccessCallback,
+                                                         () -> placeManager.goTo(uncloseablePlaces.get(0)));
         }
-
-        closingLibraryPlaces = false;
     }
 
     public void closePlace(final Command successCallback,
@@ -828,8 +673,9 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
             uncloseablePlaces.add(place);
             closeUnsavedProjectAssetsPopUpPresenter.show(getActiveWorkspace(),
                                                          uncloseablePlaces,
-                                                         Optional.of(newSuccessCallback),
-                                                         Optional.empty());
+                                                         newSuccessCallback,
+                                                         () -> {
+                                                         });
         }
     }
 
@@ -839,15 +685,39 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         closingLibraryPlaces = false;
     }
 
-    public WorkspaceProjectContext getWorkbenchContext(){
+    public WorkspaceProjectContext getWorkbenchContext() {
         return projectContext;
     }
 
-
     public WorkspaceProject getActiveWorkspace() {
         return this.projectContext.getActiveWorkspaceProject().orElseThrow(() -> new IllegalStateException("No active workspace project found"));
     }
 
+    public OrganizationalUnit getActiveSpace() {
+        return this.projectContext.getActiveOrganizationalUnit().orElseThrow(() -> new IllegalStateException("No active space found"));
+    }
+
+    public boolean isThisUserAccessingThisRepository(final User user,
+                                                     final Repository repository) {
+        return isThisRepositoryBeingAccessed(repository) && sessionInfo.getIdentity().equals(user);
+    }
+
+    public boolean isThisRepositoryBeingAccessed(final Repository repository) {
+        final Space space = repository.getSpace();
+        final String repositoryAlias = repository.getAlias();
+
+        if (this.projectContext.getActiveOrganizationalUnit().isPresent()
+                && this.projectContext.getActiveWorkspaceProject().isPresent()) {
+            final Space activeSpace = this.projectContext.getActiveOrganizationalUnit().get().getSpace();
+            final Repository activeRepository = this.projectContext.getActiveWorkspaceProject().get().getRepository();
+            final String activeRepositoryAlias = activeRepository.getAlias();
+
+            return space.equals(activeSpace) && repositoryAlias.equals(activeRepositoryAlias);
+        }
+
+        return false;
+    }
+
     public void init(final LibraryPerspective libraryPerspective) {
         this.libraryPerspective = libraryPerspective;
     }
@@ -861,8 +731,9 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                 closeAllPlacesOrNothing(this::goToProject);
             }
 
-            if (Utils.hasModuleChanged(previous.getModule(), current.getModule())) {
-                setupLibraryBreadCrumbs(projectContext.getActiveWorkspaceProject().get());
+            if (Utils.hasModuleChanged(previous.getModule(),
+                                       current.getModule())) {
+                libraryBreadcrumbs.setupForProject(projectContext.getActiveWorkspaceProject().get());
             }
         }
     }
