@@ -42,6 +42,7 @@ import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.SessionInfoMock;
+import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 
@@ -157,10 +158,13 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
-        verify(libraryService).createProject("test",
-                                             organizationalUnit,
-                                             "description",
-                                             DeploymentMode.VALIDATED);
+        final ArgumentCaptor<POM> pomArgumentCaptor = ArgumentCaptor.forClass(POM.class);
+
+        verify(view).setAddButtonEnabled(false);
+        verify(libraryService).createProject(eq(organizationalUnit),
+                                             pomArgumentCaptor.capture(),
+                                             eq(DeploymentMode.VALIDATED));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -179,9 +183,11 @@ public class AddProjectPopUpPresenterTest {
 
         final ArgumentCaptor<POM> pomArgumentCaptor = ArgumentCaptor.forClass(POM.class);
 
+        verify(view).setAddButtonEnabled(false);
         verify(libraryService).createProject(eq(organizationalUnit),
                                              pomArgumentCaptor.capture(),
                                              eq(DeploymentMode.VALIDATED));
+        verify(view).setAddButtonEnabled(true);
 
         final POM pom = pomArgumentCaptor.getValue();
 
@@ -190,6 +196,47 @@ public class AddProjectPopUpPresenterTest {
         assertEquals("groupId", pom.getGav().getGroupId());
         assertEquals("artifactId", pom.getGav().getArtifactId());
         assertEquals("version", pom.getGav().getVersion());
+
+        //Checking default kie-server options
+        assertEquals("kjar", pom.getPackaging());
+        assertEquals("org.kie", pom.getBuild().getPlugins().get(0).getGroupId());
+        assertEquals("kie-maven-plugin", pom.getBuild().getPlugins().get(0).getArtifactId());
+    }
+
+    @Test
+    public void newWorkbenchProjectWithQuickSettingsIsCreated() throws Exception {
+        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
+        when(projectContext.getActiveOrganizationalUnit()).thenReturn(Optional.of(organizationalUnit));
+
+        doReturn("test").when(view).getName();
+        doReturn("description").when(view).getDescription();
+        doReturn("groupId").when(view).getGroupId();
+        doReturn("artifactId").when(view).getArtifactId();
+        doReturn("version").when(view).getVersion();
+        doReturn(false).when(view).isAdvancedOptionsSelected();
+
+        presenter.add();
+
+        final ArgumentCaptor<POM> pomArgumentCaptor = ArgumentCaptor.forClass(POM.class);
+
+        verify(view).setAddButtonEnabled(false);
+        verify(libraryService).createProject(eq(organizationalUnit),
+                                             pomArgumentCaptor.capture(),
+                                             eq(DeploymentMode.VALIDATED));
+        verify(view).setAddButtonEnabled(true);
+
+        final POM pom = pomArgumentCaptor.getValue();
+
+        assertEquals("test", pom.getName());
+        assertEquals("description", pom.getDescription());
+        assertEquals("groupId", pom.getGav().getGroupId());
+        assertEquals("artifactId", pom.getGav().getArtifactId());
+        assertEquals("version", pom.getGav().getVersion());
+
+        //Checking default kie-server options
+        assertEquals("kjar", pom.getPackaging());
+        assertEquals("org.kie", pom.getBuild().getPlugins().get(0).getGroupId());
+        assertEquals("kie-maven-plugin", pom.getBuild().getPlugins().get(0).getArtifactId());
     }
 
     @Test
@@ -199,7 +246,9 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
+        verify(view).setAddButtonEnabled(true);
         verify(newProjectEvent).fire(any(NewProjectEvent.class));
         verify(view).hide();
         verify(notificationEvent).fire(any(NotificationEvent.class));
@@ -211,15 +260,15 @@ public class AddProjectPopUpPresenterTest {
         doReturn("test").when(view).getName();
         doReturn("description").when(view).getDescription();
 
-        doThrow(new FileAlreadyExistsException()).when(libraryService).createProject(anyString(),
+        doThrow(new FileAlreadyExistsException()).when(libraryService).createProject(any(),
                                                                                      any(),
-                                                                                     anyString(),
                                                                                      any());
         doAnswer(invocationOnMock -> ((Throwable) invocationOnMock.getArguments()[0]).getCause() instanceof FileAlreadyExistsException)
                 .when(presenter).isDuplicatedProjectName(any());
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -229,6 +278,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -242,6 +292,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -251,6 +302,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -264,6 +316,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -273,6 +326,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -286,6 +340,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -295,6 +350,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -308,6 +364,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -317,6 +374,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -332,6 +390,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -341,6 +400,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -356,6 +416,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -365,6 +426,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -380,6 +442,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -389,6 +452,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
     }
 
     @Test
@@ -404,6 +468,7 @@ public class AddProjectPopUpPresenterTest {
 
         presenter.add();
 
+        verify(view).setAddButtonEnabled(false);
         verify(view).showBusyIndicator(anyString());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
@@ -413,5 +478,21 @@ public class AddProjectPopUpPresenterTest {
         verify(view).showError(anyString());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
+        verify(view).setAddButtonEnabled(true);
+    }
+
+    @Test
+    public void createProjectWithExternalSuccessCallbackTest() {
+        doReturn("test").when(view).getName();
+        doReturn("description").when(view).getDescription();
+        ParameterizedCommand<WorkspaceProject> command = mock(ParameterizedCommand.class);
+        presenter.setSuccessCallback(command);
+
+        presenter.add();
+
+        verify(view).setAddButtonEnabled(false);
+        verify(view).showBusyIndicator(anyString());
+        verify(view).setAddButtonEnabled(true);
+        verify(command).execute(any());
     }
 }
