@@ -21,12 +21,12 @@ import javax.enterprise.event.Event;
 
 import elemental2.dom.HTMLElement;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
-import org.guvnor.common.services.project.client.security.ProjectController;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
+import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.Module;
+import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
-import org.guvnor.messageconsole.client.console.widget.button.ViewHideAlertsButtonPresenter;
-import org.guvnor.structure.client.security.OrganizationalUnitController;
+import org.guvnor.structure.repositories.Branch;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
@@ -36,19 +36,22 @@ import org.kie.workbench.common.screens.defaulteditor.client.editor.NewFileUploa
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.client.screens.ProjectScreenTestBase;
 import org.kie.workbench.common.screens.library.client.screens.assets.AssetsScreen;
-import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.edit.EditContributorsPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ContributorsListPresenter;
+import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ProjectContributorsListServiceImpl;
+import org.kie.workbench.common.screens.library.client.screens.project.actions.ProjectMainActions;
+import org.kie.workbench.common.screens.library.client.screens.project.branch.delete.DeleteBranchPopUpScreen;
 import org.kie.workbench.common.screens.library.client.screens.project.delete.DeleteProjectPopUpScreen;
 import org.kie.workbench.common.screens.library.client.screens.project.rename.RenameProjectPopUpScreen;
 import org.kie.workbench.common.screens.library.client.settings.SettingsPresenter;
+import org.kie.workbench.common.screens.library.client.util.LibraryPermissions;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
-import org.kie.workbench.common.screens.projecteditor.client.build.BuildExecutor;
 import org.kie.workbench.common.screens.projecteditor.client.validation.ProjectNameValidator;
 import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
 import org.kie.workbench.common.widgets.client.handlers.NewResourcePresenter;
 import org.mockito.Answers;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
+import org.uberfire.backend.vfs.Path;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.FileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
@@ -59,8 +62,9 @@ import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyString;
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyString;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -94,10 +98,7 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     private ProjectMetricsScreen projectMetrictsScreen;
 
     @Mock
-    private ProjectController projectController;
-
-    @Mock
-    private OrganizationalUnitController organizationalUnitController;
+    private LibraryPermissions libraryPermissions;
 
     @Mock(answer = Answers.RETURNS_DEEP_STUBS)
     private NewFileUploader newFileUploader;
@@ -105,21 +106,18 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     @Mock
     private NewResourcePresenter newResourcePresenter;
 
-    @Mock
-    private BuildExecutor buildExecutor;
-
-    @Mock
-    private ManagedInstance<EditContributorsPopUpPresenter> editContributorsPopUpPresenterInstance;
-
-    @Mock
-    private EditContributorsPopUpPresenter editContributorsPopUpPresenter;
-
     @Mock
     private ManagedInstance<DeleteProjectPopUpScreen> deleteProjectPopUpScreenInstance;
 
     @Mock
     private DeleteProjectPopUpScreen deleteProjectPopUpScreen;
 
+    @Mock
+    private ManagedInstance<DeleteBranchPopUpScreen> deleteBranchPopUpScreenInstance;
+
+    @Mock
+    private DeleteBranchPopUpScreen deleteBranchPopUpScreen;
+
     @Mock
     private ManagedInstance<RenameProjectPopUpScreen> renameProjectPopUpScreenInstance;
 
@@ -146,13 +144,10 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     private Event<NotificationEvent> notificationEvent;
 
     @Mock
-    private ViewHideAlertsButtonPresenter viewHideAlertsButtonPresenter;
+    private ProjectContributorsListServiceImpl projectContributorsListService;
 
     @Mock
-    private ViewHideAlertsButtonPresenter.View viewHideAlertsButtonView;
-
-    @Mock
-    private WorkspaceProject workspaceProject;
+    private ProjectMainActions projectMainActions;
 
     private SyncPromises promises;
 
@@ -162,17 +157,11 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         promises = spy(new SyncPromises());
 
         when(assetsScreen.getView()).thenReturn(assetsView);
-        when(viewHideAlertsButtonPresenter.getView()).thenReturn(viewHideAlertsButtonView);
 
-        when(editContributorsPopUpPresenterInstance.get()).thenReturn(editContributorsPopUpPresenter);
         when(deleteProjectPopUpScreenInstance.get()).thenReturn(deleteProjectPopUpScreen);
+        when(deleteBranchPopUpScreenInstance.get()).thenReturn(deleteBranchPopUpScreen);
         when(renameProjectPopUpScreenInstance.get()).thenReturn(renameProjectPopUpScreen);
 
-        final Module module = mock(Module.class);
-        when(workspaceProject.getName()).thenReturn("module-name");
-        when(workspaceProject.getMainModule()).thenReturn(module);
-        when(libraryPlaces.getActiveWorkspace()).thenReturn(workspaceProject);
-
         final WorkspaceProjectContext projectContext = mock(WorkspaceProjectContext.class);
         when(libraryPlaces.getWorkbenchContext()).thenReturn(projectContext);
 
@@ -181,14 +170,12 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
                                                               this.assetsScreen,
                                                               this.contributorsListScreen,
                                                               this.projectMetrictsScreen,
-                                                              this.projectController,
+                                                              this.libraryPermissions,
                                                               this.settingsPresenter,
-                                                              this.organizationalUnitController,
                                                               this.newFileUploader,
                                                               this.newResourcePresenter,
-                                                              this.buildExecutor,
-                                                              this.editContributorsPopUpPresenterInstance,
                                                               this.deleteProjectPopUpScreenInstance,
+                                                              this.deleteBranchPopUpScreenInstance,
                                                               this.renameProjectPopUpScreenInstance,
                                                               new CallerMock<>(this.libraryService),
                                                               projectScreenServiceCaller,
@@ -196,10 +183,12 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
                                                               projectNameValidator,
                                                               promises,
                                                               notificationEvent,
-                                                              viewHideAlertsButtonPresenter);
+                                                              projectContributorsListService,
+                                                              projectMainActions);
         this.presenter = spy(projectScreen);
 
-        this.presenter.workspaceProject = createProject();
+        this.presenter.workspaceProject = spy(createProject());
+        when(libraryPlaces.getActiveWorkspace()).thenReturn(this.presenter.workspaceProject);
     }
 
     @Test
@@ -207,9 +196,10 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         presenter.initialize();
 
         verify(view).init(presenter);
-        verify(buildExecutor).init(view);
-        verify(view).setTitle("module-name");
-        verify(view).addMainAction(viewHideAlertsButtonView);
+        verify(view).setTitle("mainModuleName");
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
@@ -220,30 +210,14 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
 
         verify(view).setAddAssetVisible(true);
         verify(view).setImportAssetVisible(true);
-        verify(view).setEditContributorsVisible(false);
         verify(view).setDuplicateVisible(false);
         verify(view).setReimportVisible(true);
         verify(view).setDeleteProjectVisible(false);
-        verify(view).setBuildEnabled(false);
-        verify(view).setDeployEnabled(false);
-        verify(view).setActionsVisible(true);
-    }
-
-    @Test
-    public void testActionsVisibilityWithPermissionToUpdateSpaceOnly() {
-        doReturn(true).when(this.presenter).canEditContributors();
-
-        presenter.initialize();
-
-        verify(view).setAddAssetVisible(false);
-        verify(view).setImportAssetVisible(false);
-        verify(view).setEditContributorsVisible(true);
-        verify(view).setDuplicateVisible(false);
-        verify(view).setReimportVisible(false);
-        verify(view).setDeleteProjectVisible(false);
-        verify(view).setBuildEnabled(false);
-        verify(view).setDeployEnabled(false);
+        verify(view).setDeleteBranchVisible(false);
         verify(view).setActionsVisible(true);
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
@@ -254,13 +228,14 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
 
         verify(view).setAddAssetVisible(false);
         verify(view).setImportAssetVisible(false);
-        verify(view).setEditContributorsVisible(false);
         verify(view).setDuplicateVisible(false);
         verify(view).setReimportVisible(false);
         verify(view).setDeleteProjectVisible(true);
-        verify(view).setBuildEnabled(false);
-        verify(view).setDeployEnabled(false);
+        verify(view).setDeleteBranchVisible(false);
         verify(view).setActionsVisible(true);
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
@@ -271,13 +246,32 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
 
         verify(view).setAddAssetVisible(false);
         verify(view).setImportAssetVisible(false);
-        verify(view).setEditContributorsVisible(false);
         verify(view).setDuplicateVisible(false);
         verify(view).setReimportVisible(false);
         verify(view).setDeleteProjectVisible(false);
-        verify(view).setBuildEnabled(true);
-        verify(view).setDeployEnabled(true);
+        verify(view).setDeleteBranchVisible(false);
         verify(view).setActionsVisible(true);
+        verify(projectMainActions).setBuildEnabled(eq(true));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
+    }
+
+    @Test
+    public void testActionsVisibilityWithPermissionToDeployProjectOnly() {
+        doReturn(true).when(this.presenter).userCanDeployProject();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(false);
+        verify(view).setDeleteBranchVisible(false);
+        verify(view).setActionsVisible(true);
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(true));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
@@ -288,13 +282,14 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
 
         verify(view).setAddAssetVisible(false);
         verify(view).setImportAssetVisible(false);
-        verify(view).setEditContributorsVisible(false);
         verify(view).setDuplicateVisible(true);
         verify(view).setReimportVisible(false);
         verify(view).setDeleteProjectVisible(false);
-        verify(view).setBuildEnabled(false);
-        verify(view).setDeployEnabled(false);
+        verify(view).setDeleteBranchVisible(false);
         verify(view).setActionsVisible(true);
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
@@ -303,13 +298,33 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
 
         verify(view).setAddAssetVisible(false);
         verify(view).setImportAssetVisible(false);
-        verify(view).setEditContributorsVisible(false);
         verify(view).setDuplicateVisible(false);
         verify(view).setReimportVisible(false);
         verify(view).setDeleteProjectVisible(false);
-        verify(view).setBuildEnabled(false);
-        verify(view).setDeployEnabled(false);
+        verify(view).setDeleteBranchVisible(false);
         verify(view).setActionsVisible(false);
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
+    }
+
+    @Test
+    public void testActionsVisibilityWithPermissionToDeleteProjectInCreatedBranch() {
+        doReturn(true).when(this.presenter).userCanDeleteProject();
+        doReturn(new Branch("other-branch", mock(Path.class))).when(presenter.workspaceProject).getBranch();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(true);
+        verify(view).setDeleteBranchVisible(true);
+        verify(view).setActionsVisible(true);
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
@@ -372,54 +387,6 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         }
     }
 
-    @Test
-    public void testEditContributors() {
-        {
-            doReturn(false).when(this.presenter).canEditContributors();
-            this.presenter.editContributors();
-            verify(this.editContributorsPopUpPresenter,
-                   never()).show(any());
-        }
-        {
-            doReturn(true).when(this.presenter).canEditContributors();
-            this.presenter.editContributors();
-            verify(this.editContributorsPopUpPresenter,
-                   times(1)).show(any());
-        }
-    }
-
-    @Test
-    public void testDeploy() {
-        {
-            doReturn(false).when(this.presenter).userCanBuildProject();
-            this.presenter.deploy();
-            verify(this.buildExecutor,
-                   never()).triggerBuildAndDeploy();
-        }
-        {
-            doReturn(true).when(this.presenter).userCanBuildProject();
-            this.presenter.deploy();
-            verify(this.buildExecutor,
-                   times(1)).triggerBuildAndDeploy();
-        }
-    }
-
-    @Test
-    public void testBuild() {
-        {
-            doReturn(false).when(this.presenter).userCanBuildProject();
-            this.presenter.build();
-            verify(this.buildExecutor,
-                   never()).triggerBuild();
-        }
-        {
-            doReturn(true).when(this.presenter).userCanBuildProject();
-            this.presenter.build();
-            verify(this.buildExecutor,
-                   times(1)).triggerBuild();
-        }
-    }
-
     @Test
     public void testDuplicate() {
         {
@@ -485,38 +452,57 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     }
 
     @Test
-    public void canBuild() throws Exception {
-        doReturn(true).when(projectController).canBuildProject(any(WorkspaceProject.class));
+    public void canBuild() {
+        doReturn(true).when(libraryPermissions).userCanBuildProject(any(WorkspaceProject.class));
         assertTrue(presenter.userCanBuildProject());
     }
 
     @Test
-    public void notAllowedToBuild() throws Exception {
-        doReturn(false).when(projectController).canBuildProject(any(WorkspaceProject.class));
+    public void notAllowedToBuild() {
+        doReturn(false).when(libraryPermissions).userCanBuildProject(any(WorkspaceProject.class));
         assertFalse(presenter.userCanBuildProject());
     }
 
     @Test
-    public void allowedToBuildButNoModule() throws Exception {
-        doReturn(null).when(workspaceProject).getMainModule();
-        presenter.initialize();
-        doReturn(true).when(projectController).canBuildProject(workspaceProject);
-
-        assertFalse(presenter.userCanBuildProject());
-    }
-
-    @Test
-    public void titleIsUpdatedWhenContextModuleIsUpdated() throws Exception {
+    public void testContextModuleIsUpdated() {
         final WorkspaceProject workspaceProject = mock(WorkspaceProject.class);
         doReturn("module name").when(workspaceProject).getName();
 
+        final Module module = mock(Module.class);
+        when(module.getPom()).thenReturn(new POM(new GAV(GROUP_ID, ARTIFACT, VERSION)));
+
+        when(workspaceProject.getMainModule()).thenReturn(module);
+
         presenter.changeProjectAndTitleWhenContextChange(new WorkspaceProjectContextChangeEvent(workspaceProject));
 
         verify(view).setTitle("module name");
+
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(false));
     }
 
     @Test
-    public void shouldNotChangeProjectAndTitleWhenContextChange() throws Exception {
+    public void testContextModuleIsUpdatedSapshot() {
+        final WorkspaceProject workspaceProject = mock(WorkspaceProject.class);
+        doReturn("module name").when(workspaceProject).getName();
+
+        final Module module = mock(Module.class);
+        when(module.getPom()).thenReturn(new POM(new GAV(GROUP_ID, ARTIFACT, VERSION + "-SNAPSHOT")));
+
+        when(workspaceProject.getMainModule()).thenReturn(module);
+
+        presenter.changeProjectAndTitleWhenContextChange(new WorkspaceProjectContextChangeEvent(workspaceProject));
+
+        verify(view).setTitle("module name");
+
+        verify(projectMainActions).setBuildEnabled(eq(false));
+        verify(projectMainActions).setDeployEnabled(eq(false));
+        verify(projectMainActions).setRedeployEnabled(eq(true));
+    }
+
+    @Test
+    public void shouldNotChangeProjectAndTitleWhenContextChange() {
 
         presenter.changeProjectAndTitleWhenContextChange(new WorkspaceProjectContextChangeEvent() {
             @Override
