@@ -1,6 +1,5 @@
 package org.kie.workbench.common.screens.library.client.settings.sections.generalsettings;
 
-import com.google.gwt.core.client.GWT;
 import org.guvnor.common.services.project.client.preferences.ProjectScopedResolutionStrategySupplier;
 import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.POM;
@@ -29,20 +28,24 @@ import org.uberfire.promise.SyncPromises;
 
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.doNothing;
-import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.never;
-import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
+import static org.mockito.Mockito.*;
 
 @RunWith(MockitoJUnitRunner.class)
 public class GeneralSettingsPresenterTest {
 
-    @Mock
+    private static final String GROUP = "org.test";
+    private static final String ARTIFACT = "artifact";
+    private static final String VERSION = "1.0";
+
+    private POM pom;
+
+    private GAV gav;
+
     private GeneralSettingsPresenter generalSettingsPresenter;
 
+    @Mock
+    private ProjectScreenModel model;
+
     @Mock
     private GeneralSettingsView view;
 
@@ -81,6 +84,14 @@ public class GeneralSettingsPresenterTest {
 
     @Before
     public void before() {
+        gav = spy(new GAV(GROUP, ARTIFACT, VERSION));
+
+        pom = spy(new POM());
+
+        when(pom.getGav()).thenReturn(gav);
+
+        when(model.getPOM()).thenReturn(pom);
+
         projectServiceCaller = new CallerMock<>(projectService);
         generalSettingsPresenter = spy(new GeneralSettingsPresenter(view,
                                                                     promises,
@@ -100,12 +111,6 @@ public class GeneralSettingsPresenterTest {
     @Test
     public void testSetup() {
 
-        final ProjectScreenModel model = mock(ProjectScreenModel.class);
-        final POM pom = mock(POM.class);
-
-        doReturn(pom).when(model).getPOM();
-        doReturn(new GAV()).when(pom).getGav();
-
         generalSettingsPresenter.setup(model).catch_(i -> {
             Assert.fail("Promise should've been resolved!");
             return promises.resolve();
@@ -117,18 +122,16 @@ public class GeneralSettingsPresenterTest {
         verify(view).setGroupId(any());
         verify(view).setArtifactId(any());
         verify(view).setVersion(any());
+
         verify(view).setGitUrlsView(any());
 
         verify(gitUrlsPresenter).setup(any());
 
-        verify(gavPreferences).load(any(),
-                                    any(),
-                                    any());
+        verify(gavPreferences).load(any(), any(), any());
     }
 
     @Test
     public void testName() {
-        final POM pom = spy(new POM());
         generalSettingsPresenter.pom = pom;
 
         generalSettingsPresenter.setName("Name");
@@ -140,7 +143,6 @@ public class GeneralSettingsPresenterTest {
 
     @Test
     public void testDescription() {
-        final POM pom = spy(new POM());
         generalSettingsPresenter.pom = pom;
 
         generalSettingsPresenter.setDescription("Description");
@@ -152,8 +154,6 @@ public class GeneralSettingsPresenterTest {
 
     @Test
     public void testVersion() {
-        final POM pom = spy(new POM());
-        doReturn(new GAV()).when(pom).getGav();
         generalSettingsPresenter.pom = pom;
 
         generalSettingsPresenter.setVersion("Version");
@@ -165,8 +165,6 @@ public class GeneralSettingsPresenterTest {
 
     @Test
     public void testArtifactId() {
-        final POM pom = spy(new POM());
-        doReturn(new GAV()).when(pom).getGav();
         generalSettingsPresenter.pom = pom;
 
         generalSettingsPresenter.setArtifactId("ArtifactId");
@@ -178,8 +176,6 @@ public class GeneralSettingsPresenterTest {
 
     @Test
     public void testGroupId() {
-        final POM pom = spy(new POM());
-        doReturn(new GAV()).when(pom).getGav();
         generalSettingsPresenter.pom = pom;
 
         generalSettingsPresenter.setGroupId("GroupId");
