@@ -16,15 +16,28 @@
 
 package org.kie.workbench.common.workbench.client.menu;
 
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMINISTRATION;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.APPS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASET_AUTHORING;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASOURCE_MANAGEMENT;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.LIBRARY;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PLUGIN_AUTHORING;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_DEFINITIONS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_INSTANCES;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.SOCIAL_HOME;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.SOCIAL_USER_HOME;
+import static org.uberfire.workbench.model.menu.MenuFactory.newSimpleItem;
+
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import java.util.Set;
+
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 
-import com.google.gwt.core.client.GWT;
-import com.google.gwt.i18n.client.LocaleInfo;
 import org.dashbuilder.navigation.NavDivider;
 import org.dashbuilder.navigation.NavGroup;
 import org.dashbuilder.navigation.NavItem;
@@ -46,6 +59,7 @@ import org.uberfire.client.menu.WorkbenchViewModeSwitcherMenuBuilder;
 import org.uberfire.client.mvp.ActivityManager;
 import org.uberfire.client.mvp.PerspectiveActivity;
 import org.uberfire.client.mvp.PerspectiveManager;
+import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.views.pfly.menu.UserMenu;
 import org.uberfire.client.workbench.widgets.menu.UtilityMenuBar;
 import org.uberfire.client.workbench.widgets.menu.megamenu.WorkbenchMegaMenuPresenter;
@@ -57,25 +71,14 @@ import org.uberfire.security.ResourceRef;
 import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.workbench.model.ActivityResourceType;
 import org.uberfire.workbench.model.menu.MenuFactory;
+import org.uberfire.workbench.model.menu.MenuFactory.Builder;
+import org.uberfire.workbench.model.menu.MenuFactory.MenuBuilder;
+import org.uberfire.workbench.model.menu.MenuFactory.TopLevelMenusBuilder;
 import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
 
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMINISTRATION;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.APPS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASET_AUTHORING;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASOURCE_MANAGEMENT;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.LIBRARY;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PLUGIN_AUTHORING;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_DEFINITIONS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_INSTANCES;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SOCIAL_HOME;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SOCIAL_USER_HOME;
-import static org.uberfire.workbench.model.menu.MenuFactory.Builder;
-import static org.uberfire.workbench.model.menu.MenuFactory.MenuBuilder;
-import static org.uberfire.workbench.model.menu.MenuFactory.TopLevelMenusBuilder;
-import static org.uberfire.workbench.model.menu.MenuFactory.newSimpleItem;
+import com.google.gwt.core.client.GWT;
+import com.google.gwt.i18n.client.LocaleInfo;
 
 @ApplicationScoped
 public class DefaultWorkbenchFeaturesMenusHelper {
@@ -93,6 +96,7 @@ public class DefaultWorkbenchFeaturesMenusHelper {
     protected AboutCommand aboutCommand;
     private AuthorizationManager authorizationManager;
     private SessionInfo sessionInfo;
+    private PlaceManager placeManager;
 
     public DefaultWorkbenchFeaturesMenusHelper() {
     }
@@ -108,7 +112,8 @@ public class DefaultWorkbenchFeaturesMenusHelper {
                                                WorkbenchMegaMenuPresenter menuBar,
                                                AboutCommand aboutCommand,
                                                AuthorizationManager authorizationManager,
-                                               SessionInfo sessionInfo) {
+                                               SessionInfo sessionInfo,
+                                               PlaceManager placeManager) {
         this.iocManager = iocManager;
         this.activityManager = activityManager;
         this.perspectiveManager = perspectiveManager;
@@ -120,6 +125,7 @@ public class DefaultWorkbenchFeaturesMenusHelper {
         this.aboutCommand = aboutCommand;
         this.authorizationManager = authorizationManager;
         this.sessionInfo = sessionInfo;
+        this.placeManager = placeManager;
     }
 
     public List<? extends MenuItem> getHomeViews(final boolean socialEnabled) {
@@ -165,10 +171,8 @@ public class DefaultWorkbenchFeaturesMenusHelper {
 
     public List<? extends MenuItem> getProcessManagementViews() {
         final List<MenuItem> result = new ArrayList<>(2);
-
         result.add(MenuFactory.newSimpleItem(constants.ProcessDefinitions()).perspective(PROCESS_DEFINITIONS).endMenu().build().getItems().get(0));
         result.add(MenuFactory.newSimpleItem(constants.ProcessInstances()).perspective(PROCESS_INSTANCES).endMenu().build().getItems().get(0));
-
         return result;
     }
 
@@ -363,7 +367,10 @@ public class DefaultWorkbenchFeaturesMenusHelper {
 
         @Override
         public void execute() {
-            perspectiveManager.savePerspectiveState(() -> doRedirect(getRedirectURL()));
+            perspectiveManager.savePerspectiveState(() -> {
+                placeManager.closePlace(perspectiveManager.getCurrentPerspectivePlaceRequest(),
+                                        () -> doRedirect(getRedirectURL()));
+            });
             // request.logout() happens as part of the redirected logout.jsp
         }
 
@@ -396,4 +403,5 @@ public class DefaultWorkbenchFeaturesMenusHelper {
     public static native void redirect(String url)/*-{
         $wnd.location = url;
     }-*/;
-}
+
+}
\ No newline at end of file
