@@ -31,6 +31,7 @@ import org.kie.workbench.common.stunner.client.lienzo.shape.view.ViewEventHandle
 import org.kie.workbench.common.stunner.client.lienzo.shape.view.wires.WiresShapeView;
 import org.kie.workbench.common.stunner.client.lienzo.util.LienzoShapeUtils;
 import org.kie.workbench.common.stunner.client.lienzo.util.ShapeControlPointsHelper;
+import org.kie.workbench.common.stunner.core.client.shape.TextWrapperStrategy;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasControlPoints;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasEventHandlers;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasFillGradient;
@@ -50,11 +51,10 @@ import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewHandler
 
 public class WiresShapeViewExt<T extends WiresShapeViewExt>
         extends WiresShapeView<T>
-        implements
-        HasTitle<T>,
-        HasControlPoints<T>,
-        HasEventHandlers<T, Shape<?>>,
-        HasFillGradient<T> {
+        implements HasTitle<T>,
+                   HasControlPoints<T>,
+                   HasEventHandlers<T, Shape<?>>,
+                   HasFillGradient<T> {
 
     private ViewEventHandlerManager eventHandlerManager;
     private WiresTextDecorator textViewDecorator;
@@ -80,10 +80,14 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
 
     protected void setEventHandlerManager(final ViewEventHandlerManager eventHandlerManager) {
         this.eventHandlerManager = eventHandlerManager;
-        setTextViewDecorator(new WiresTextDecorator(() -> eventHandlerManager));
+        setTextViewDecorator(new WiresTextDecorator(() -> eventHandlerManager, getPath().getBoundingBox()));
         addTextAsChild();
     }
 
+    protected ViewEventHandlerManager getEventHandlerManager() {
+        return this.eventHandlerManager;
+    }
+
     void setTextViewDecorator(final WiresTextDecorator textViewDecorator) {
         this.textViewDecorator = textViewDecorator;
     }
@@ -115,6 +119,18 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
         return cast();
     }
 
+    @Override
+    public T setTitleXOffsetPosition(final Double xOffset) {
+        textViewDecorator.setTitleXOffsetPosition(xOffset);
+        return cast();
+    }
+
+    @Override
+    public T setTitleYOffsetPosition(final Double yOffset) {
+        textViewDecorator.setTitleYOffsetPosition(yOffset);
+        return cast();
+    }
+
     @Override
     @SuppressWarnings("unchecked")
     public T setTitleRotation(final double degrees) {
@@ -163,6 +179,18 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
         return cast();
     }
 
+    @Override
+    public T setTitleStrokeAlpha(final double strokeAlpha){
+        textViewDecorator.setTitleStrokeAlpha(strokeAlpha);
+        return cast();
+    }
+
+    @Override
+    public T setTextWrapper(final TextWrapperStrategy wrapperStrategy){
+        textViewDecorator.setTextWrapper(wrapperStrategy);
+        return(cast());
+    }
+
     @Override
     @SuppressWarnings("unchecked")
     public T moveTitleToTop() {
@@ -294,7 +322,6 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
             }
             if (ViewEventType.TEXT_DBL_CLICK.equals(type)) {
                 textViewDecorator.setTextDblClickHandler((ViewHandler<TextDoubleClickEvent>) eventHandler);
-                delegate = false;
             }
             if (delegate) {
                 eventHandlerManager.addHandler(type,
@@ -391,7 +418,7 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
         return new HandlerRegistration[]{r0, r1, r2};
     }
 
-    private DragEvent buildDragEvent(final AbstractWiresDragEvent sourceDragEvent) {
+    protected DragEvent buildDragEvent(final AbstractWiresDragEvent sourceDragEvent) {
         final double x = sourceDragEvent.getX();
         final double y = sourceDragEvent.getY();
         final double cx = sourceDragEvent.getNodeDragEvent().getX();
@@ -408,7 +435,7 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
                              dragContext);
     }
 
-    private ResizeEvent buildResizeEvent(final AbstractWiresResizeEvent sourceResizeEvent) {
+    protected ResizeEvent buildResizeEvent(final AbstractWiresResizeEvent sourceResizeEvent) {
         final double x = sourceResizeEvent.getX();
         final double y = sourceResizeEvent.getY();
         final double cx = sourceResizeEvent.getNodeDragEvent().getX();
@@ -424,7 +451,7 @@ public class WiresShapeViewExt<T extends WiresShapeViewExt>
     }
 
     @SuppressWarnings("unchecked")
-    private T cast() {
+    protected T cast() {
         return (T) this;
     }
 }
