@@ -23,7 +23,6 @@ import java.util.function.Consumer;
 
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
-import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import org.jboss.errai.common.client.api.IsElement;
@@ -32,10 +31,11 @@ import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.stunner.client.widgets.palette.categories.DefinitionPaletteCategoryWidget;
 import org.kie.workbench.common.stunner.client.widgets.palette.categories.items.DefinitionPaletteItemWidget;
+import org.kie.workbench.common.stunner.client.widgets.palette.collapsed.CollapsedDefinitionPaletteItemWidget;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
-import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasFocusedEvent;
 import org.kie.workbench.common.stunner.core.client.components.glyph.ShapeGlyphDragHandler;
 import org.kie.workbench.common.stunner.core.client.components.palette.AbstractPalette;
+import org.kie.workbench.common.stunner.core.client.components.palette.CollapsedDefaultPaletteItem;
 import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteCategory;
 import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteDefinition;
 import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteItem;
@@ -50,8 +50,6 @@ import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeFactory;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.kie.workbench.common.stunner.core.preferences.StunnerPreferences;
 
-import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
-
 @Dependent
 public class BS3PaletteWidgetImpl
         extends AbstractPalette<DefaultPaletteDefinition>
@@ -66,6 +64,7 @@ public class BS3PaletteWidgetImpl
     private final StunnerPreferencesRegistries preferencesRegistries;
     private final ManagedInstance<DefinitionPaletteCategoryWidget> categoryWidgetInstances;
     private final ManagedInstance<DefinitionPaletteItemWidget> definitionPaletteItemWidgetInstances;
+    private final ManagedInstance<CollapsedDefinitionPaletteItemWidget> collapsedDefinitionPaletteItemWidgets;
     private Consumer<PaletteIDefinitionItemEvent> itemDropCallback;
     private Consumer<PaletteIDefinitionItemEvent> itemDragStartCallback;
     private Consumer<PaletteIDefinitionItemEvent> itemDragUpdateCallback;
@@ -80,7 +79,8 @@ public class BS3PaletteWidgetImpl
                                 final ShapeGlyphDragHandler shapeGlyphDragHandler,
                                 final StunnerPreferencesRegistries preferencesRegistries,
                                 final ManagedInstance<DefinitionPaletteCategoryWidget> categoryWidgetInstance,
-                                final ManagedInstance<DefinitionPaletteItemWidget> definitionPaletteItemWidgets) {
+                                final ManagedInstance<DefinitionPaletteItemWidget> definitionPaletteItemWidgets,
+                                final ManagedInstance<CollapsedDefinitionPaletteItemWidget> collapsedDefinitionPaletteItemWidgets) {
         super(shapeManager);
         this.clientFactoryServices = clientFactoryServices;
         this.view = view;
@@ -88,6 +88,7 @@ public class BS3PaletteWidgetImpl
         this.preferencesRegistries = preferencesRegistries;
         this.categoryWidgetInstances = categoryWidgetInstance;
         this.definitionPaletteItemWidgetInstances = definitionPaletteItemWidgets;
+        this.collapsedDefinitionPaletteItemWidgets = collapsedDefinitionPaletteItemWidgets;
     }
 
     public static int getDefaultWidth() {
@@ -192,7 +193,7 @@ public class BS3PaletteWidgetImpl
     @SuppressWarnings("unchecked")
     protected AbstractPalette<DefaultPaletteDefinition> bind() {
         if (null != paletteDefinition) {
-            final StunnerPreferences preferences = preferencesRegistries.get(paletteDefinition.getDefinitionSetId());
+            final StunnerPreferences preferences = preferencesRegistries.get(paletteDefinition.getDefinitionSetId(), StunnerPreferences.class);
             final boolean autoHidePanel = preferences.getDiagramEditorPreferences().isAutoHidePalettePanel();
             paletteDefinition.getItems().forEach(item -> {
                 BS3PaletteWidgetPresenter widget;
@@ -204,6 +205,8 @@ public class BS3PaletteWidgetImpl
                     categoryWidgets.put(item.getId(),
                                         categoryWidget);
                     widget = categoryWidget;
+                } else if (item instanceof CollapsedDefaultPaletteItem) {
+                    widget = newCollapsedDefinitionPaletteItemWidget();
                 } else {
                     widget = newDefinitionPaletteItemWidget();
                 }
@@ -238,7 +241,14 @@ public class BS3PaletteWidgetImpl
 
     @Override
     public Glyph getShapeGlyph(final String definitionId) {
-        return getShapeFactory().getGlyph(definitionId);
+        return getShapeFactory().getGlyph(definitionId,
+                                          AbstractPalette.PaletteGlyphConsumer.class);
+    }
+
+    @Override
+    public Glyph getShapeDragProxyGlyph(final String definitionId) {
+        return getShapeFactory().getGlyph(definitionId,
+                                          AbstractPalette.PaletteDragProxyGlyphConsumer.class);
     }
 
     private void handleMouseDownEvent(final DefaultPaletteItem item,
@@ -288,17 +298,13 @@ public class BS3PaletteWidgetImpl
         widget.setVisible(false);
     }
 
-    void onCanvasFocusedEvent(final @Observes CanvasFocusedEvent canvasFocusedEvent) {
-        checkNotNull("canvasFocusedEvent",
-                     canvasFocusedEvent);
-    }
-
     @Override
     protected void doDestroy() {
         shapeGlyphDragHandler.destroy();
         view.destroy();
         categoryWidgetInstances.destroyAll();
         definitionPaletteItemWidgetInstances.destroyAll();
+        collapsedDefinitionPaletteItemWidgets.destroyAll();
         itemDragStartCallback = null;
         itemDragUpdateCallback = null;
         itemDropCallback = null;
@@ -320,6 +326,10 @@ public class BS3PaletteWidgetImpl
         return definitionPaletteItemWidgetInstances.get();
     }
 
+    protected CollapsedDefinitionPaletteItemWidget newCollapsedDefinitionPaletteItemWidget() {
+        return collapsedDefinitionPaletteItemWidgets.get();
+    }
+
     @Override
     public HTMLElement getElement() {
         return view.getElement();
