@@ -17,12 +17,15 @@
 package org.kie.workbench.common.stunner.client.widgets.explorer.tree;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
+import java.util.OptionalInt;
 
 import com.google.gwt.user.client.ui.IsWidget;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.jboss.errai.common.client.api.IsElement;
 import org.jboss.errai.common.client.ui.ElementWrapperWidget;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -30,13 +33,17 @@ import org.kie.workbench.common.stunner.client.widgets.components.glyph.DOMGlyph
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.client.ShapeSet;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
+import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProvider;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProviderFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasClearEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementUpdatedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeFactory;
 import org.kie.workbench.common.stunner.core.definition.adapter.AdapterManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
+import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionId;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
@@ -45,6 +52,7 @@ import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
+import org.kie.workbench.common.stunner.core.graph.content.relationship.Child;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.impl.NodeImpl;
 import org.kie.workbench.common.stunner.core.graph.processing.traverse.content.AbstractChildrenTraverseCallback;
@@ -54,13 +62,21 @@ import org.kie.workbench.common.stunner.core.graph.processing.traverse.tree.Tree
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
 import org.uberfire.mocks.EventSourceMock;
+import org.uberfire.mvp.Command;
 
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.anyBoolean;
 import static org.mockito.Mockito.anyDouble;
 import static org.mockito.Mockito.anyObject;
+import static org.mockito.Mockito.atLeastOnce;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
@@ -89,6 +105,9 @@ public class TreeExplorerTest {
     @Mock
     TreeExplorerView view;
 
+    @Mock
+    ManagedInstance<TreeExplorer.View> views;
+
     @Mock
     DOMGlyphRenderers domGlyphRenderers;
 
@@ -104,6 +123,9 @@ public class TreeExplorerTest {
     @Mock
     CanvasHandler canvasHandler;
 
+    @Mock
+    Canvas canvas;
+
     @Mock
     DefinitionManager definitionManager;
 
@@ -132,6 +154,8 @@ public class TreeExplorerTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() {
+        when(views.get()).thenReturn(view);
+        when(canvasHandler.getCanvas()).thenReturn(canvas);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(canvasHandler.getDiagram().getGraph()).thenReturn(graph);
         when(diagram.getMetadata()).thenReturn(metadata);
@@ -140,47 +164,31 @@ public class TreeExplorerTest {
         when(definitionUtils.getDefinitionManager()).thenReturn(definitionManager);
         when(definitionManager.adapters()).thenReturn(adapterManager);
         when(adapterManager.forDefinition()).thenReturn(definitionAdapter);
-        when(definitionAdapter.getId(anyObject())).thenReturn("defId");
+        when(definitionAdapter.getId(anyObject())).thenReturn(DefinitionId.build("defId"));
         when(shapeManager.getShapeSet(eq(SHAPE_SET_ID))).thenReturn(shapeSet);
         when(shapeSet.getShapeFactory()).thenReturn(shapeFactory);
         when(shapeFactory.getGlyph(eq("defId"))).thenReturn(glyph);
         when(domGlyphRenderers.render(eq(glyph),
                                       anyDouble(),
                                       anyDouble())).thenReturn(isElement);
+        when(graph.nodes()).thenReturn(getMockNodes());
 
         this.childrenTraverseProcessor = spy(new ChildrenTraverseProcessorImpl(new TreeWalkTraverseProcessorImpl()));
 
-        this.testedTree = new TreeExplorer(childrenTraverseProcessor,
-                                           textPropertyProviderFactory,
-                                           elementSelectedEvent,
-                                           definitionUtils,
-                                           shapeManager,
-                                           domGlyphRenderers,
-                                           view) {
-
-            @Override
-            ElementWrapperWidget<?> wrapIconElement(final IsElement icon) {
-                return mock(ElementWrapperWidget.class);
-            }
-        };
-    }
-
-    @Test
-    public void testInit() {
-        testedTree.init();
-        verify(view,
-               times(1)).init(eq(testedTree));
+        this.testedTree = createTestInstance();
     }
 
     @Test
     public void testClear() {
+        testedTree.show(canvasHandler);
         testedTree.clear();
         verify(view,
-               times(1)).clear();
+               atLeastOnce()).clear();
     }
 
     @Test
     public void testDestroy() {
+        testedTree.show(canvasHandler);
         testedTree.destroy();
         verify(view,
                times(1)).destroy();
@@ -189,10 +197,9 @@ public class TreeExplorerTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testShow() {
-        when(graph.nodes()).thenReturn(getMockNodes());
-
         testedTree.show(canvasHandler);
-
+        verify(view,
+               times(1)).init(eq(testedTree));
         verify(childrenTraverseProcessor,
                times(1)).traverse(eq(graph),
                                   any(AbstractChildrenTraverseCallback.class));
@@ -255,6 +262,82 @@ public class TreeExplorerTest {
                              anyBoolean());
     }
 
+    @Test
+    public void testNotFiringSelectionEventFromObservers() {
+        testedTree = spy(createTestInstance());
+        final CanvasClearEvent clearEvent = mock(CanvasClearEvent.class);
+        when(clearEvent.getCanvas()).thenReturn(canvas);
+        testedTree.show(canvasHandler);
+        Command runnable = () -> {
+            assertTrue(testedTree.isEventInProgress());
+            testedTree.onSelect("someUUID");
+            verify(elementSelectedEvent,
+                   never()).fire(any(CanvasSelectionEvent.class));
+        };
+        testedTree.checkEventContext(clearEvent,
+                                     runnable);
+        assertFalse(testedTree.isEventInProgress());
+    }
+
+    @Test
+    public void testOnElementUpdated_childHighlighted() {
+        final Node parent = mock(Node.class);
+        when(parent.getUUID()).thenReturn("PARENT_UUID");
+        when(parent.getContent()).thenReturn(mock(View.class));
+
+        final Node child = mock(Node.class);
+        when(child.getUUID()).thenReturn("CHILD_UUID");
+        when(child.getContent()).thenReturn(mock(View.class));
+
+        final Edge edge = mock(Edge.class);
+        when(edge.getSourceNode()).thenReturn(parent);
+        when(edge.getTargetNode()).thenReturn(child);
+        when(edge.getContent()).thenReturn(mock(Child.class));
+
+        final List<Edge> edges = Collections.singletonList(edge);
+        when(parent.getOutEdges()).thenReturn(edges);
+        when(child.getInEdges()).thenReturn(edges);
+
+        when(view.isItemChanged(anyString(), anyString(), anyString(), any(OptionalInt.class))).thenReturn(true);
+
+        testedTree.show(canvasHandler);
+        final CanvasElementUpdatedEvent event = new CanvasElementUpdatedEvent(canvasHandler, child);
+        testedTree.onCanvasElementUpdatedEvent(event);
+
+        verify(view, times(1)).setSelectedItem(eq("CHILD_UUID"));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testErrorHandling() {
+        doThrow(new RuntimeException()).when(childrenTraverseProcessor)
+                .traverse(any(Graph.class), any(AbstractChildrenTraverseCallback.class));
+
+        try {
+            testedTree.show(canvasHandler);
+        } catch (Exception ex) {
+            fail();
+        }
+
+        verify(view, times(2)).clear();
+    }
+
+    private TreeExplorer createTestInstance() {
+        return new TreeExplorer(childrenTraverseProcessor,
+                                textPropertyProviderFactory,
+                                elementSelectedEvent,
+                                definitionUtils,
+                                shapeManager,
+                                domGlyphRenderers,
+                                views) {
+
+            @Override
+            ElementWrapperWidget<?> wrapIconElement(final IsElement icon) {
+                return mock(ElementWrapperWidget.class);
+            }
+        };
+    }
+
     private Iterable<Node<Content, Edge>> getMockNodes(final String... uuids) {
         final List<Node<Content, Edge>> nodes = new ArrayList<>();
         for (String uuid : uuids) {
