@@ -21,20 +21,23 @@ import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.client.widgets.canvas.ScrollableLienzoPanel;
 import org.kie.workbench.common.stunner.client.widgets.presenters.AbstractCanvasHandlerViewerTest;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionViewer;
 import org.kie.workbench.common.stunner.client.widgets.views.WidgetWrapperView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.CanvasPanel;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
+import org.kie.workbench.common.stunner.core.client.preferences.StunnerPreferencesRegistries;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Element;
+import org.kie.workbench.common.stunner.core.preferences.StunnerPreferences;
 import org.mockito.Mock;
 import org.uberfire.mvp.ParameterizedCommand;
 
@@ -42,6 +45,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -49,12 +53,14 @@ import static org.mockito.Mockito.when;
 @RunWith(GwtMockitoTestRunner.class)
 public class SessionEditorTest extends AbstractCanvasHandlerViewerTest {
 
+    private static final String DEFINITION_SET_ID = "definitionSetId";
+
     @Mock
-    AbstractClientFullSession session;
+    EditorSession session;
     @Mock
-    SessionViewer.SessionViewerCallback<AbstractClientFullSession, Diagram> callback;
+    SessionViewer.SessionViewerCallback<Diagram> callback;
     @Mock
-    CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager;
+    ScrollableLienzoPanel canvasPanel;
     @Mock
     ZoomControl<AbstractCanvas> zoomControl;
     @Mock
@@ -67,8 +73,12 @@ public class SessionEditorTest extends AbstractCanvasHandlerViewerTest {
     DockingAcceptorControl<AbstractCanvasHandler> dockingAcceptorControl;
     @Mock
     WidgetWrapperView view;
+    @Mock
+    StunnerPreferencesRegistries preferencesRegistries;
+    @Mock
+    StunnerPreferences stunnerPreferences;
 
-    private SessionEditorImpl<AbstractClientFullSession, AbstractCanvasHandler> tested;
+    private SessionEditorImpl<EditorSession> tested;
 
     @Before
     public void setup() throws Exception {
@@ -81,8 +91,9 @@ public class SessionEditorTest extends AbstractCanvasHandlerViewerTest {
         when(session.getConnectionAcceptorControl()).thenReturn(connectionAcceptorControl);
         when(session.getContainmentAcceptorControl()).thenReturn(containmentAcceptorControl);
         when(session.getDockingAcceptorControl()).thenReturn(dockingAcceptorControl);
-        this.tested = new SessionEditorImpl<AbstractClientFullSession, AbstractCanvasHandler>(canvasCommandManager,
-                                                                                              view);
+        when(metadata.getDefinitionSetId()).thenReturn(DEFINITION_SET_ID);
+        when(preferencesRegistries.get(DEFINITION_SET_ID, StunnerPreferences.class)).thenReturn(stunnerPreferences);
+        this.tested = new SessionEditorImpl<>(view, canvasPanel, preferencesRegistries);
     }
 
     @Test
@@ -133,8 +144,13 @@ public class SessionEditorTest extends AbstractCanvasHandlerViewerTest {
         tested.destroy();
         assertNull(tested.getInstance());
         verify(canvasHandler,
-               times(1)).destroy();
+               never()).destroy();
         verify(view,
                times(1)).clear();
     }
+
+    @Override
+    protected CanvasPanel getCanvasPanel() {
+        return canvasPanel;
+    }
 }
