@@ -16,29 +16,29 @@
 
 package org.kie.workbench.common.stunner.core.client.session.command.impl;
 
-import java.util.Objects;
-
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Observes;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher;
-import org.kie.workbench.common.stunner.core.client.canvas.event.command.CanvasCommandExecutedEvent;
-import org.kie.workbench.common.stunner.core.client.canvas.event.command.CanvasUndoCommandExecutedEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.registration.RegisterChangedEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
-import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher.doKeysMatch;
 
 @Dependent
-public class UndoSessionCommand extends AbstractClientSessionCommand<ClientFullSession> {
+@Default
+public class UndoSessionCommand extends AbstractClientSessionCommand<EditorSession> {
 
     private final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
@@ -53,19 +53,28 @@ public class UndoSessionCommand extends AbstractClientSessionCommand<ClientFullS
     }
 
     @Override
-    public void bind(final ClientFullSession session) {
+    public void bind(final EditorSession session) {
         super.bind(session);
-        session.getKeyboardControl().addKeyShortcutCallback(keys -> {
-            if (isUndoShortcut(keys)) {
-                UndoSessionCommand.this.execute();
-            }
-        });
+        session.getKeyboardControl().addKeyShortcutCallback(this::onKeyDownEvent);
     }
 
-    private boolean isUndoShortcut(final KeyboardEvent.Key... keys) {
-        return KeysMatcher.doKeysMatch(keys,
-                                       KeyboardEvent.Key.CONTROL,
-                                       KeyboardEvent.Key.Z);
+    @Override
+    public boolean accepts(final ClientSession session) {
+        return session instanceof EditorSession;
+    }
+
+    void onKeyDownEvent(final KeyboardEvent.Key... keys) {
+        if (isEnabled()) {
+            handleCtrlZ(keys);
+        }
+    }
+
+    private void handleCtrlZ(final KeyboardEvent.Key[] keys) {
+        if (doKeysMatch(keys,
+                        KeyboardEvent.Key.CONTROL,
+                        KeyboardEvent.Key.Z)) {
+            this.execute();
+        }
     }
 
     @Override
@@ -75,10 +84,12 @@ public class UndoSessionCommand extends AbstractClientSessionCommand<ClientFullS
                      callback);
         final SessionCommandManager<AbstractCanvasHandler> scm = getSessionCommandManager();
         if (null != scm) {
-            final CommandResult<CanvasViolation> result = getSessionCommandManager().undo((AbstractCanvasHandler) getSession().getCanvasHandler());
+            final CommandResult<CanvasViolation> result = getSessionCommandManager().undo(getSession().getCanvasHandler());
             checkState();
             if (CommandUtils.isError(result)) {
                 callback.onError((V) result);
+                // Clear the actual command registry otherwise the undo will continuously fail as it's same command.
+                getSessionCommandManager().getRegistry().clear();
             } else {
                 callback.onSuccess();
             }
@@ -86,27 +97,12 @@ public class UndoSessionCommand extends AbstractClientSessionCommand<ClientFullS
         }
     }
 
-    void onCommandExecuted(final @Observes CanvasCommandExecutedEvent commandExecutedEvent) {
-        checkNotNull("commandExecutedEvent",
-                     commandExecutedEvent);
+    void onCommandAdded(final @Observes RegisterChangedEvent registerChangedEvent) {
+        checkNotNull("registerChangedEvent",
+                     registerChangedEvent);
         checkState();
     }
 
-    void onCommandUndoExecuted(final @Observes CanvasUndoCommandExecutedEvent commandUndoExecutedEvent) {
-        checkNotNull("commandUndoExecutedEvent",
-                     commandUndoExecutedEvent);
-        checkState();
-    }
-
-    void onClearSessionExecuted(final @Observes ClearSessionCommandExecutedEvent event) {
-        checkNotNull("event",
-                     event);
-        if (Objects.equals(getSession(),
-                           event.getClientSession())) {
-            checkState();
-        }
-    }
-
     private void checkState() {
         if (null != getSession()) {
             final SessionCommandManager<AbstractCanvasHandler> cm = getSessionCommandManager();
