@@ -41,11 +41,11 @@ import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
+import org.kie.workbench.common.stunner.core.graph.content.Bound;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.content.relationship.Child;
 import org.kie.workbench.common.stunner.core.graph.content.relationship.Dock;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
@@ -61,7 +61,7 @@ import static org.kie.workbench.common.stunner.core.graph.util.GraphUtils.getPos
  * A Command to clone a node and set as a child of the given parent.
  */
 @Portable
-public final class CloneNodeCommand extends AbstractGraphCompositeCommand {
+public class CloneNodeCommand extends AbstractGraphCompositeCommand {
 
     private final Node<Definition, Edge> candidate;
     private final Optional<String> parentUuidOptional;
@@ -113,12 +113,18 @@ public final class CloneNodeCommand extends AbstractGraphCompositeCommand {
         cloneNodeContentWithProperties(context);
 
         //creating node commands to be executed
-        addCommand(new RegisterNodeCommand(clone));
-        addCommand(new AddChildNodeCommand(parentUUID.get(), clone, position));
+        createNodeCommands(clone, parentUUID.get(), position);
 
         return this;
     }
 
+    protected void createNodeCommands(final Node<View, Edge> clone,
+                                      final String parentUUID,
+                                      final Point2D position) {
+        addCommand(new RegisterNodeCommand(clone));
+        addCommand(new AddChildNodeCommand(parentUUID, clone, position));
+    }
+
     void cloneNodeContentWithProperties(final GraphCommandExecutionContext context) {
 
         final View cloneContent = getClone().getContent();
@@ -133,9 +139,9 @@ public final class CloneNodeCommand extends AbstractGraphCompositeCommand {
     }
 
     Bounds cloneBounds(final Bounds bounds) {
-        final Bounds.Bound ul = bounds.getUpperLeft();
-        final Bounds.Bound lr = bounds.getLowerRight();
-        return BoundsImpl.build(ul.getX(), ul.getY(), lr.getX(), lr.getY());
+        final Bound ul = bounds.getUpperLeft();
+        final Bound lr = bounds.getLowerRight();
+        return Bounds.create(ul.getX(), ul.getY(), lr.getX(), lr.getY());
     }
 
     @Override
@@ -164,8 +170,14 @@ public final class CloneNodeCommand extends AbstractGraphCompositeCommand {
         //in case of any error than rollback all commands
         CommandResult<RuleViolation> finalResult = buildResult(commandResults);
         if (CommandUtils.isError(finalResult)) {
-            undoMultipleExecutedCommands(context, childrenCommands);
-            undoMultipleExecutedCommands(context, getCommands());
+            processMultipleFunctions(childrenCommands,
+                                     c -> doUndo(context, c),
+                                     reverted -> {
+                                     });
+            processMultipleFunctions(getCommands(),
+                                     c -> doUndo(context, c),
+                                     reverted -> {
+                                     });
             return finalResult;
         }
 
@@ -185,11 +197,11 @@ public final class CloneNodeCommand extends AbstractGraphCompositeCommand {
             public boolean startNodeTraversal(final List<Node<View, Edge>> parents,
                                               final Node<View, Edge> node) {
                 //clone child and map clone uuid
-                CloneNodeCommand command = new CloneNodeCommand(node,
-                                                                clone.getUUID(),
-                                                                getPosition((View) node.getContent()),
-                                                                childClone -> cloneNodeMapUUID.put(node.getUUID(), childClone),
-                                                                childrenTraverseProcessor);
+                CloneNodeCommand command = createCloneChildCommand(node,
+                                                                   clone.getUUID(),
+                                                                   getPosition(node.getContent()),
+                                                                   childClone -> cloneNodeMapUUID.put(node.getUUID(), childClone),
+                                                                   childrenTraverseProcessor);
                 childrenCommands.add(command);
                 commandResults.add(command.execute(context));
                 //just traverse the first level children of the root node
@@ -227,6 +239,18 @@ public final class CloneNodeCommand extends AbstractGraphCompositeCommand {
         return commandResults;
     }
 
+    protected CloneNodeCommand createCloneChildCommand(final Node candidate,
+                                                       final String parentUuid,
+                                                       final Point2D position,
+                                                       final Consumer<Node> callback,
+                                                       final ManagedInstance<ChildrenTraverseProcessor> childrenTraverseProcessor) {
+        return new CloneNodeCommand(candidate,
+                                    parentUuid,
+                                    position,
+                                    callback,
+                                    childrenTraverseProcessor);
+    }
+
     private List<CommandResult<RuleViolation>> processDockedNodes(GraphCommandExecutionContext context) {
         return candidate.getOutEdges().stream()
                 .filter(edge -> edge.getContent() instanceof Dock)
