@@ -38,6 +38,7 @@ public class CoreTranslationMessages {
     public static final String REASON = CORE_PREF + "reason";
     public static final String DELETE = CORE_PREF + "delete";
     public static final String EDIT = CORE_PREF + "edit";
+    public static final String PRINT = CORE_PREF + "print";
     public static final String ARE_YOU_SURE = CORE_PREF + "areYouSure";
     public static final String ELEMENT_UUID = CORE_PREF + "element_uuid";
     public static final String COMMAND_SUCCESS = COMMAND_PREF + "success";
@@ -45,6 +46,7 @@ public class CoreTranslationMessages {
     public static final String VALIDATION_SUCCESS = RULE_PREF + "success";
     public static final String VALIDATION_FAILED = RULE_PREF + "fail";
     public static final String DIAGRAM_LOAD_FAIL_UNSUPPORTED_ELEMENTS = "org.kie.workbench.common.stunner.core.client.diagram.load.fail.unsupported";
+    public static final String DIAGRAM_AUTOMATIC_LAYOUT_PERFORMED = "org.kie.workbench.common.stunner.core.client.diagram.automatic.layout.performed";
     public static final String COPY_SELECTION = "org.kie.workbench.common.stunner.core.client.toolbox.CopySelection";
     public static final String CUT_SELECTION = "org.kie.workbench.common.stunner.core.client.toolbox.CutSelection";
     public static final String PASTE_SELECTION = "org.kie.workbench.common.stunner.core.client.toolbox.PasteSelection";
@@ -63,6 +65,7 @@ public class CoreTranslationMessages {
     public static final String CLEAR_DIAGRAM = "org.kie.workbench.common.stunner.core.client.toolbox.ClearDiagram";
     public static final String CLEAR_SHAPES = "org.kie.workbench.common.stunner.core.client.toolbox.ClearShapes";
     public static final String CONFIRM_CLEAR_DIAGRAM = "org.kie.workbench.common.stunner.core.client.toolbox.ConfirmClearDiagram";
+    public static final String PERFORM_AUTOMATIC_LAYOUT = "org.kie.workbench.common.stunner.core.client.toolbox.PerformAutomaticLayout";
     public static final String NEW_LINE = "\n";
     public static final String DOT = ".";
     public static final String COLON = ": ";
