@@ -17,14 +17,16 @@
 package org.kie.workbench.common.stunner.core.util;
 
 import java.lang.annotation.Annotation;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
 import java.util.Set;
 
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 
+import org.kie.soup.commons.util.Maps;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
@@ -41,9 +43,10 @@ import org.kie.workbench.common.stunner.core.definition.property.type.StringType
 import org.kie.workbench.common.stunner.core.factory.graph.EdgeFactory;
 import org.kie.workbench.common.stunner.core.factory.graph.ElementFactory;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
+import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
+import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
+import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.registry.factory.FactoryRegistry;
 import org.kie.workbench.common.stunner.core.registry.impl.DefinitionsCacheRegistry;
 
@@ -87,13 +90,29 @@ public class DefinitionUtils {
     }
 
     public <T> String getName(final T definition) {
-        final Object name =
-                definitionManager.adapters().forDefinition().getMetaProperty(PropertyMetaTypes.NAME,
-                                                                             definition);
-        if (null != name) {
-            return (String) definitionManager.adapters().forProperty().getValue(name);
+        final Optional<String> nameField = definitionManager.adapters()
+                .forDefinition()
+                .getNameField(definition);
+
+        //first try to get by name field from Definition annotation
+        if (nameField.isPresent()) {
+            return getPropertyValueAsString(GraphUtils.getPropertyByField(definitionManager,
+                                                                          definition,
+                                                                          nameField.get()));
         }
-        return null;
+
+        //default getting by metadata
+        return Optional.ofNullable(definitionManager.adapters()
+                                           .forDefinition()
+                                           .getMetaProperty(PropertyMetaTypes.NAME, definition))
+                .map(this::getPropertyValueAsString)
+                .orElse(null);
+    }
+
+    private String getPropertyValueAsString(Object property) {
+        return Optional.ofNullable(definitionManager.adapters().forProperty().getValue(property))
+                .map(String::valueOf)
+                .orElse("");
     }
 
     public <T> String getTitle(final String definitionId) {
@@ -131,19 +150,21 @@ public class DefinitionUtils {
 
         final double _width = null != width ? width : 0d;
         final double _height = null != height ? height : 0d;
-        return new BoundsImpl(new BoundImpl(x,
-                                            y),
-                              new BoundImpl(x + _width,
-                                            y + _height));
+        return Bounds.create(x, y, x + _width, y + _height);
     }
 
     public <T> String getNameIdentifier(final T definition) {
-        final Object name = definitionManager.adapters().forDefinition().getMetaProperty(PropertyMetaTypes.NAME,
-                                                                                         definition);
-        if (null != name) {
-            return definitionManager.adapters().forProperty().getId(name);
-        }
-        return null;
+        return definitionManager.adapters()
+                .forDefinition()
+                .getNameField(definition)
+                .orElseGet(
+                        () -> Optional.ofNullable(definitionManager.adapters()
+                                                          .forDefinition()
+                                                          .getMetaProperty(PropertyMetaTypes.NAME, definition))
+                                .filter(Objects::nonNull)
+                                .map(name -> definitionManager.adapters().forProperty().getId(name))
+                                .orElse(null)
+                );
     }
 
     public <T> MorphDefinition getMorphDefinition(final T definition) {
@@ -185,7 +206,7 @@ public class DefinitionUtils {
     public <T> String[] getDefinitionIds(final T definition) {
         final Class<?> type = definition.getClass();
         final DefinitionAdapter<Object> definitionAdapter = definitionManager.adapters().registry().getDefinitionAdapter(type);
-        final String definitionId = definitionAdapter.getId(definition);
+        final String definitionId = definitionAdapter.getId(definition).value();
         String baseId = null;
         if (definitionAdapter instanceof HasInheritance) {
             baseId = ((HasInheritance) definitionAdapter).getBaseType(type);
@@ -193,26 +214,6 @@ public class DefinitionUtils {
         return new String[]{definitionId, baseId};
     }
 
-    public String getDefaultConnectorId(final String definitionSetId) {
-        final Object defSet = getDefinitionManager().definitionSets().getDefinitionSetById(definitionSetId);
-        if (null != defSet) {
-            final Set<String> definitions = definitionManager.adapters().forDefinitionSet().getDefinitions(defSet);
-            if (null != definitions && !definitions.isEmpty()) {
-                for (final String defId : definitions) {
-                    final Object def = definitionsRegistry.getDefinitionById(defId);
-                    if (null != def) {
-                        final Class<? extends ElementFactory> graphElement = definitionManager.adapters().forDefinition().getGraphFactoryType(def);
-                        if (isEdgeFactory(graphElement,
-                                          factoryManager.registry())) {
-                            return defId;
-                        }
-                    }
-                }
-            }
-        }
-        return null;
-    }
-
     public boolean isAllPolicy(final MorphDefinition definition) {
         return ClonePolicy.ALL.equals(definition.getPolicy());
     }
@@ -229,6 +230,10 @@ public class DefinitionUtils {
         checkNotNull("defSetId",
                      defSetId);
         final Object ds = definitionManager.definitionSets().getDefinitionSetById(defSetId);
+        return getQualifier(ds);
+    }
+
+    private Annotation getQualifier(final Object ds) {
         return definitionManager.adapters().forDefinitionSet().getQualifier(ds);
     }
 
@@ -291,18 +296,26 @@ public class DefinitionUtils {
         return definitionManager;
     }
 
-    private static final Map<Class<?>, Class<? extends PropertyType>> DEFAULT_PROPERTY_TYPES = new HashMap<Class<?>, Class<? extends PropertyType>>() {{
-        put(String.class,
-            StringType.class);
-        put(Double.class,
-            DoubleType.class);
-        put(Integer.class,
-            IntegerType.class);
-        put(Boolean.class,
-            BooleanType.class);
-    }};
+    private static final Map<Class<?>, Class<? extends PropertyType>> DEFAULT_PROPERTY_TYPES = new Maps.Builder<Class<?>, Class<? extends PropertyType>>()
+            .put(String.class,
+                 StringType.class)
+            .put(Double.class,
+                 DoubleType.class)
+            .put(Integer.class,
+                 IntegerType.class)
+            .put(Boolean.class,
+                 BooleanType.class)
+            .build();
 
     public static Class<? extends PropertyType> getDefaultPropertyType(final Class<?> clazz) {
         return DEFAULT_PROPERTY_TYPES.get(clazz);
     }
+
+    public static Object getElementDefinition(final Element element) {
+        if (element != null && element.getContent() instanceof Definition) {
+            return ((Definition) element.getContent()).getDefinition();
+        } else {
+            return null;
+        }
+    }
 }
