@@ -26,7 +26,10 @@ import org.kie.workbench.common.stunner.core.definition.adapter.PropertyAdapter;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
+import org.kie.workbench.common.stunner.core.graph.command.ContextualGraphCommandExecutionContext;
+import org.kie.workbench.common.stunner.core.graph.command.DirectGraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
+import org.kie.workbench.common.stunner.core.graph.content.Bound;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
@@ -42,6 +45,7 @@ import org.mockito.MockitoAnnotations;
 
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
 
 public abstract class AbstractGraphCommandTest {
@@ -49,8 +53,6 @@ public abstract class AbstractGraphCommandTest {
     private static final String GRAPH_UUID = "graphUUID";
     protected final RuleViolations EMPTY_VIOLATIONS = new DefaultRuleViolations();
 
-    @Mock
-    protected GraphCommandExecutionContext graphCommandExecutionContext;
     @Mock
     protected DefinitionManager definitionManager;
     @Mock
@@ -74,17 +76,12 @@ public abstract class AbstractGraphCommandTest {
     @Mock
     protected DefinitionSet graphContent;
 
+    protected GraphCommandExecutionContext graphCommandExecutionContext;
     protected Collection<Node> graphNodes = new LinkedList<>();
 
     @SuppressWarnings("unchecked")
-    public void init(final double width,
-                     final double height) {
+    public void init() {
         MockitoAnnotations.initMocks(this);
-        Bounds bounds = mockBounds(0,
-                                   0,
-                                   width,
-                                   height);
-        when(graphContent.getBounds()).thenReturn(bounds);
         when(graph.getUUID()).thenReturn(GRAPH_UUID);
         when(graph.getContent()).thenReturn(graphContent);
         when(graph.nodes()).thenReturn(graphNodes);
@@ -94,16 +91,20 @@ public abstract class AbstractGraphCommandTest {
         when(adapterManager.forProperty()).thenReturn(propertyAdapter);
         when(adapterRegistry.getDefinitionAdapter(any(Class.class))).thenReturn(definitionAdapter);
         when(adapterRegistry.getPropertyAdapter(any(Class.class))).thenReturn(propertyAdapter);
-        when(graphCommandExecutionContext.getDefinitionManager()).thenReturn(definitionManager);
-        when(graphCommandExecutionContext.getFactoryManager()).thenReturn(factoryManager);
-        when(graphCommandExecutionContext.getRuleManager()).thenReturn(ruleManager);
-        when(graphCommandExecutionContext.getGraphIndex()).thenReturn(graphIndex);
-        when(graphCommandExecutionContext.getRuleSet()).thenReturn(ruleSet);
+        graphCommandExecutionContext = spy(new ContextualGraphCommandExecutionContext(definitionManager, factoryManager, ruleManager, graphIndex, ruleSet));
         when(graphIndex.getGraph()).thenReturn(graph);
         when(ruleManager.evaluate(any(RuleSet.class),
                                   any(RuleEvaluationContext.class))).thenReturn(EMPTY_VIOLATIONS);
     }
 
+    protected DirectGraphCommandExecutionContext createAllowedExecutionContext() {
+        return new DirectGraphCommandExecutionContext(definitionManager, factoryManager, graphIndex);
+    }
+
+    protected void useAllowedExecutionContext() {
+        graphCommandExecutionContext = createAllowedExecutionContext();
+    }
+
     public static Node mockNode(String uuid) {
         Node node = mock(Node.class);
         when(node.getUUID()).thenReturn(uuid);
@@ -138,8 +139,8 @@ public abstract class AbstractGraphCommandTest {
                                     final double w,
                                     final double h) {
         Bounds bounds = mock(Bounds.class);
-        Bounds.Bound boundUL = mock(Bounds.Bound.class);
-        Bounds.Bound boundLR = mock(Bounds.Bound.class);
+        Bound boundUL = mock(Bound.class);
+        Bound boundLR = mock(Bound.class);
         when(boundUL.getX()).thenReturn(x);
         when(boundUL.getY()).thenReturn(y);
         when(boundLR.getX()).thenReturn(x + w);
