@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.core.graph.command.impl;
 
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
 
@@ -44,6 +45,7 @@ import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -69,8 +71,7 @@ public class SetConnectionSourceNodeCommandTest extends AbstractGraphCommandTest
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
-        super.init(500,
-                   500);
+        super.init();
         node = mockNode(NODE_UUID);
         lastSourceNode = mockNode(LAST_SOURCE_NODE_UUID);
         target = mockNode(TARGET_UUID);
@@ -128,7 +129,7 @@ public class SetConnectionSourceNodeCommandTest extends AbstractGraphCommandTest
     @Test
     @SuppressWarnings("unchecked")
     public void testAllowNoRules() {
-        when(graphCommandExecutionContext.getRuleManager()).thenReturn(null);
+        useAllowedExecutionContext();
         CommandResult<RuleViolation> result = tested.allow(graphCommandExecutionContext);
         assertEquals(CommandResult.Type.INFO,
                      result.getType());
@@ -182,9 +183,9 @@ public class SetConnectionSourceNodeCommandTest extends AbstractGraphCommandTest
     @Test
     @SuppressWarnings("unchecked")
     public void testExecute() {
-        final List lastSourceOutEdges = mock(List.class);
-        final List sourceOutEdges = mock(List.class);
-        final List targetInEdges = mock(List.class);
+        final List lastSourceOutEdges = spy(new ArrayList());
+        final List sourceOutEdges = spy(new ArrayList());
+        final List targetInEdges = spy(new ArrayList());
         when(node.getOutEdges()).thenReturn(sourceOutEdges);
         when(lastSourceNode.getOutEdges()).thenReturn(lastSourceOutEdges);
         when(target.getInEdges()).thenReturn(targetInEdges);
