@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.core.graph.command.impl;
 
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
 
@@ -37,12 +38,17 @@ import org.kie.workbench.common.stunner.core.rule.context.GraphConnectionContext
 import org.mockito.ArgumentCaptor;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyConnection;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyConnectorCardinality;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class SetConnectionTargetNodeCommandTest extends AbstractGraphCommandTest {
@@ -65,8 +71,7 @@ public class SetConnectionTargetNodeCommandTest extends AbstractGraphCommandTest
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
-        super.init(500,
-                   500);
+        super.init();
         node = mockNode(NODE_UUID);
         lastTargetNode = mockNode(LAST_TARGET_NODE_UUID);
         source = mockNode(SOURCET_UUID);
@@ -125,7 +130,7 @@ public class SetConnectionTargetNodeCommandTest extends AbstractGraphCommandTest
     @Test
     @SuppressWarnings("unchecked")
     public void testAllowNoRules() {
-        when(graphCommandExecutionContext.getRuleManager()).thenReturn(null);
+        useAllowedExecutionContext();
         CommandResult<RuleViolation> result = tested.allow(graphCommandExecutionContext);
         assertEquals(CommandResult.Type.INFO,
                      result.getType());
@@ -179,9 +184,9 @@ public class SetConnectionTargetNodeCommandTest extends AbstractGraphCommandTest
     @Test
     @SuppressWarnings("unchecked")
     public void testExecute() {
-        final List lastTargetInEdges = mock(List.class);
-        final List sourceOutEdges = mock(List.class);
-        final List targetInEdges = mock(List.class);
+        final List lastTargetInEdges = spy(new ArrayList());
+        final List sourceOutEdges = spy(new ArrayList());
+        final List targetInEdges = spy(new ArrayList());
         when(source.getOutEdges()).thenReturn(sourceOutEdges);
         when(lastTargetNode.getInEdges()).thenReturn(lastTargetInEdges);
         when(node.getInEdges()).thenReturn(targetInEdges);
