@@ -17,10 +17,13 @@
 package org.kie.workbench.common.stunner.project.backend.service;
 
 import java.util.Map;
+import java.util.Optional;
 
 import javax.enterprise.inject.Instance;
 
 import org.guvnor.common.services.project.model.Package;
+import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.kie.workbench.common.services.backend.service.KieServiceOverviewLoader;
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
@@ -42,24 +45,26 @@ import org.uberfire.java.nio.file.StandardDeleteOption;
 
 class ProjectDiagramServiceController extends AbstractVFSDiagramService<ProjectMetadata, ProjectDiagram> {
 
-    private static final Logger LOG =
-            LoggerFactory.getLogger(ProjectDiagramServiceController.class.getName());
+    private static final Logger LOG = LoggerFactory.getLogger(ProjectDiagramServiceController.class.getName());
 
     private final IOService ioService;
     private final KieModuleService moduleService;
+    private final KieServiceOverviewLoader overviewLoader;
 
     ProjectDiagramServiceController(final DefinitionManager definitionManager,
                                     final FactoryManager factoryManager,
                                     final Instance<DefinitionSetService> definitionSetServiceInstances,
                                     final IOService ioService,
                                     final BackendRegistryFactory registryFactory,
-                                    final KieModuleService moduleService) {
+                                    final KieModuleService moduleService,
+                                    final KieServiceOverviewLoader overviewLoader) {
         super(definitionManager,
               factoryManager,
               definitionSetServiceInstances,
               registryFactory);
         this.ioService = ioService;
         this.moduleService = moduleService;
+        this.overviewLoader = overviewLoader;
     }
 
     @Override
@@ -81,19 +86,23 @@ class ProjectDiagramServiceController extends AbstractVFSDiagramService<ProjectM
                       name,
                       defSetId,
                       getCurrentModule(path).getModuleName(),
-                      null);
+                      null,
+                      Optional.empty());
     }
 
     public Path create(final Path path,
                        final String name,
                        final String defSetId,
                        final String moduleName,
-                       final Package projPkg) {
+                       final Package projectPkg,
+                       final Optional<String> projectType) {
         final ProjectMetadata metadata = buildProjectMetadataInstance(path,
                                                                       name,
                                                                       defSetId,
                                                                       moduleName,
-                                                                      projPkg);
+                                                                      projectPkg,
+                                                                      overviewLoader.loadOverview(path),
+                                                                      projectType);
         return this.create(path,
                            name,
                            defSetId,
@@ -110,7 +119,9 @@ class ProjectDiagramServiceController extends AbstractVFSDiagramService<ProjectM
                                             title,
                                             defSetId,
                                             kieModule.getModuleName(),
-                                            modulePackage);
+                                            modulePackage,
+                                            overviewLoader.loadOverview(path),
+                                            Optional.empty());
     }
 
     private KieModule getCurrentModule(final Path path) {
@@ -121,13 +132,17 @@ class ProjectDiagramServiceController extends AbstractVFSDiagramService<ProjectM
                                                          final String name,
                                                          final String defSetId,
                                                          final String moduleName,
-                                                         final Package projPkg) {
+                                                         final Package projPkg,
+                                                         final Overview overview,
+                                                         final Optional<String> projectType) {
         return new ProjectMetadataImpl.ProjectMetadataBuilder()
                 .forDefinitionSetId(defSetId)
                 .forModuleName(moduleName)
                 .forProjectPackage(projPkg)
+                .forOverview(overview)
                 .forTitle(name)
                 .forPath(path)
+                .forProjectType(projectType.orElse(null))
                 .build();
     }
 
@@ -157,6 +172,23 @@ class ProjectDiagramServiceController extends AbstractVFSDiagramService<ProjectM
         return path;
     }
 
+    public Path saveAsXml(final Path path,
+                          final String xml,
+                          final Map<String, ?> attributes,
+                          final OpenOption... comment) {
+        try {
+            getIoService().write(Paths.convert(path),
+                                 xml,
+                                 attributes,
+                                 comment);
+        } catch (Exception e) {
+            LOG.error("Error while saving diagram.",
+                      e);
+            throw new RuntimeException(e);
+        }
+        return path;
+    }
+
     @Override
     protected ProjectMetadata doSave(final ProjectDiagram diagram,
                                      final String raw,
