@@ -50,6 +50,7 @@ import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.DiagramParsingException;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
 import org.kie.workbench.common.stunner.core.preferences.StunnerDiagramEditorPreferences;
@@ -68,6 +69,7 @@ import org.kie.workbench.common.stunner.project.editor.ProjectDiagramResource;
 import org.kie.workbench.common.stunner.project.editor.impl.ProjectDiagramResourceImpl;
 import org.kie.workbench.common.stunner.project.service.ProjectDiagramResourceService;
 import org.kie.workbench.common.stunner.project.service.ProjectDiagramService;
+import org.kie.workbench.common.widgets.client.docks.DefaultEditorDock;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorWrapperView;
 import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
@@ -79,6 +81,8 @@ import org.mockito.Mock;
 import org.mockito.Spy;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.client.mvp.PerspectiveActivity;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.client.workbench.type.ClientResourceType;
@@ -108,6 +112,7 @@ import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -119,10 +124,11 @@ import static org.mockito.Mockito.when;
 @RunWith(GwtMockitoTestRunner.class)
 public class AbstractProjectDiagramEditorTest {
 
-    private static final int CANVAS_HEIGHT = 1234;
-    private static final int CANVAS_WIDTH = 5678;
     private static final String TITLE = "title";
 
+    @Mock
+    protected PerspectiveManager perspectiveManagerMock;
+
     @Mock
     protected ProjectDiagram diagram;
 
@@ -156,7 +162,7 @@ public class AbstractProjectDiagramEditorTest {
     protected ManagedInstance<SessionViewerPresenter<ViewerSession>> sessionViewerPresenters;
 
     @Mock
-    protected ProjectEditorMenuSessionItems projectMenuSessionItems;
+    protected AbstractProjectEditorMenuSessionItems projectMenuSessionItems;
 
     @Mock
     protected EventSourceMock<OnDiagramFocusEvent> onDiagramFocusEvent;
@@ -179,62 +185,44 @@ public class AbstractProjectDiagramEditorTest {
 
     @Mock
     protected WorkspaceProjectContext workbenchContext;
-
     @Mock
     protected ProjectMessagesListener projectMessagesListener;
-
     protected ClientResourceType resourceType;
-
     @Mock
     protected DiagramClientErrorHandler diagramClientErrorHandler;
-
     @Mock
     protected ClientTranslationService translationService;
-
     @Mock
     protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
-
     @Mock
     protected SessionPresenter.View sessionPresenterView;
-
     @Mock
     protected EditorSession editorSession;
-
     @Mock
     protected ViewerSession viewerSession;
-
     @Mock
     protected ObservablePath filePath;
-
     @Mock
     protected KieEditorWrapperView kieView;
-
     @Mock
     protected OverviewWidgetPresenter overviewWidget;
-
     @Mock
     protected TextEditorView xmlEditorView;
-
     @Mock
     protected Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller;
-
     @Mock
     protected StunnerDiagramEditorPreferences diagramEditorPreferences;
-
     @Mock
     protected Caller<ProjectDiagramService> diagramServiceCaller;
-
+    protected AbstractProjectDiagramEditor<ClientResourceTypeMock> presenter;
+    @Mock
+    protected DefaultEditorDock defaultEditorDock;
     @Captor
     private ArgumentCaptor<Consumer<EditorSession>> clientSessionConsumerCaptor;
-
     @Captor
     private ArgumentCaptor<SessionPresenter.SessionPresenterCallback> clientSessionPresenterCallbackCaptor;
-
-    abstract class ClientResourceTypeMock implements ClientResourceType {
-
-    }
-
-    protected AbstractProjectDiagramEditor<ClientResourceTypeMock> presenter;
+    @Mock
+    private DocumentationView viewDocumentation;
 
     @Before
     @SuppressWarnings("unchecked")
@@ -273,8 +261,6 @@ public class AbstractProjectDiagramEditorTest {
         when(getMenuSessionItems().setErrorConsumer(any(Consumer.class))).thenReturn(getMenuSessionItems());
         when(getMenuSessionItems().setLoadingCompleted(any(Command.class))).thenReturn(getMenuSessionItems());
         when(getMenuSessionItems().setLoadingStarts(any(Command.class))).thenReturn(getMenuSessionItems());
-        when(diagramEditorPreferences.getCanvasWidth()).thenReturn(CANVAS_WIDTH);
-        when(diagramEditorPreferences.getCanvasHeight()).thenReturn(CANVAS_HEIGHT);
         resourceType = mockResourceType();
         presenter = createDiagramEditor();
         presenter.init();
@@ -291,13 +277,14 @@ public class AbstractProjectDiagramEditorTest {
         return resourceType;
     }
 
-    protected ProjectEditorMenuSessionItems getMenuSessionItems() {
+    protected AbstractProjectEditorMenuSessionItems getMenuSessionItems() {
         return projectMenuSessionItems;
     }
 
     @SuppressWarnings("unchecked")
     protected AbstractProjectDiagramEditor createDiagramEditor() {
         return spy(new AbstractProjectDiagramEditor<ClientResourceTypeMock>(view,
+                                                                            viewDocumentation,
                                                                             placeManager,
                                                                             errorPopupPresenter,
                                                                             changeTitleNotificationEvent,
@@ -315,6 +302,8 @@ public class AbstractProjectDiagramEditorTest {
                                                                             xmlEditorView,
                                                                             projectDiagramResourceServiceCaller) {
             {
+                docks = AbstractProjectDiagramEditorTest.this.defaultEditorDock;
+                perspectiveManager = AbstractProjectDiagramEditorTest.this.perspectiveManagerMock;
                 fileMenuBuilder = AbstractProjectDiagramEditorTest.this.fileMenuBuilder;
                 workbenchContext = AbstractProjectDiagramEditorTest.this.workbenchContext;
                 projectController = AbstractProjectDiagramEditorTest.this.projectController;
@@ -325,16 +314,6 @@ public class AbstractProjectDiagramEditorTest {
                 notification = AbstractProjectDiagramEditorTest.this.notification;
             }
 
-            @Override
-            protected int getCanvasWidth() {
-                return 0;
-            }
-
-            @Override
-            protected int getCanvasHeight() {
-                return 0;
-            }
-
             @Override
             protected String getEditorIdentifier() {
                 return null;
@@ -347,6 +326,7 @@ public class AbstractProjectDiagramEditorTest {
 
         final Command saveAndRenameCommand = mock(Command.class);
 
+        doNothing().when(presenter).addDownloadMenuItem(any());
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
         doReturn(saveAndRenameCommand).when(presenter).getSaveAndRename();
@@ -360,10 +340,12 @@ public class AbstractProjectDiagramEditorTest {
         verify(fileMenuBuilder).addRename(saveAndRenameCommand);
         verify(fileMenuBuilder).addDelete(any(Path.class),
                                           any(AssetUpdateValidator.class));
+        verify(presenter).addDownloadMenuItem(fileMenuBuilder);
     }
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
+        doNothing().when(presenter).addDownloadMenuItem(any());
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
@@ -389,7 +371,7 @@ public class AbstractProjectDiagramEditorTest {
 
         String formattedTitle = presenter.formatTitle(title);
         assertEquals(formattedTitle,
-                     "testDiagram.bpmn - Business Process");
+                     "testDiagram." + resourceType.getSuffix() + " - " + resourceType.getShortName());
     }
 
     @Test
@@ -637,7 +619,7 @@ public class AbstractProjectDiagramEditorTest {
         final Path path = versionRecordManager.getCurrentPath();
         verify(versionRecordManager).reloadVersions(eq(path));
         ArgumentCaptor<NotificationEvent> notificationEventCaptor = ArgumentCaptor.forClass(NotificationEvent.class);
-        verify(notification).fire(notificationEventCaptor.capture());
+        verify(notification, times(2)).fire(notificationEventCaptor.capture());
 
         final NotificationEvent notificationEvent = notificationEventCaptor.getValue();
         assertEquals("ItemSavedSuccessfully",
@@ -792,4 +774,28 @@ public class AbstractProjectDiagramEditorTest {
         assertEquals(xml.hashCode(),
                      presenter.getCurrentDiagramHash());
     }
+
+    @Test
+    public void testHideDocks() {
+        presenter.hideDocks();
+
+        verify(onDiagramLostFocusEvent).fire(any());
+        verify(defaultEditorDock).hide();
+    }
+
+    @Test
+    public void testShowDocks() {
+        PerspectiveActivity perspectiveActivity = mock(PerspectiveActivity.class);
+        when(perspectiveActivity.getIdentifier()).thenReturn("perspectiveId");
+        when(perspectiveManagerMock.getCurrentPerspective()).thenReturn(perspectiveActivity);
+
+        presenter.showDocks();
+
+        verify(onDiagramFocusEvent).fire(any());
+        verify(defaultEditorDock).show();
+    }
+
+    abstract class ClientResourceTypeMock implements ClientResourceType {
+
+    }
 }
