@@ -21,9 +21,9 @@ import java.util.Objects;
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
@@ -39,17 +39,20 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Simu
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, builder = StartMessageEvent.StartMessageEventBuilder.class)
+@Definition(graphFactory = NodeFactory.class)
 @Morph(base = BaseStartEvent.class)
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class StartMessageEvent extends BaseStartEvent implements DataIOModel {
 
@@ -64,6 +67,13 @@ public class StartMessageEvent extends BaseStartEvent implements DataIOModel {
     protected DataIOSet dataIOSet;
 
     public StartMessageEvent() {
+        this(new BPMNGeneralSet(""),
+             new BackgroundSet(),
+             new FontSet(),
+             new CircleDimensionSet(new Radius()),
+             new SimulationAttributeSet(),
+             new DataIOSet(),
+             new InterruptingMessageEventExecutionSet());
     }
 
     public StartMessageEvent(final @MapsTo("general") BPMNGeneralSet general,
@@ -134,20 +144,4 @@ public class StartMessageEvent extends BaseStartEvent implements DataIOModel {
         }
         return false;
     }
-
-    @NonPortable
-    public static class StartMessageEventBuilder implements Builder<StartMessageEvent> {
-
-        @Override
-        public StartMessageEvent build() {
-            return new StartMessageEvent(new BPMNGeneralSet(""),
-                                         new BackgroundSet(),
-                                         new FontSet(),
-                                         new CircleDimensionSet(new Radius()),
-                                         new SimulationAttributeSet(),
-                                         new DataIOSet(),
-                                         new InterruptingMessageEventExecutionSet()
-            );
-        }
-    }
 }
