@@ -22,12 +22,17 @@ import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.prop
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.PropertyWriter;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.PropertyWriterFactory;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseStartEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartCompensationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartConditionalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartEscalationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartTimerEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.conditional.InterruptingConditionalEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.InterruptingErrorEventExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.InterruptingEscalationEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.InterruptingMessageEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.InterruptingSignalEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.InterruptingTimerEventExecutionSet;
@@ -52,6 +57,9 @@ public class StartEventConverter {
                 .when(StartTimerEvent.class, this::timerEvent)
                 .when(StartErrorEvent.class, this::errorEvent)
                 .when(StartMessageEvent.class, this::messageEvent)
+                .when(StartConditionalEvent.class, this::conditionalEvent)
+                .when(StartEscalationEvent.class, this::escalationEvent)
+                .when(StartCompensationEvent.class, this::compensationEvent)
                 .apply(node).value();
     }
 
@@ -166,4 +174,65 @@ public class StartEventConverter {
         p.setBounds(n.getContent().getBounds());
         return p;
     }
+
+    private PropertyWriter conditionalEvent(Node<View<StartConditionalEvent>, ?> n) {
+        StartEvent event = bpmn2.createStartEvent();
+        event.setId(n.getUUID());
+
+        StartConditionalEvent definition = n.getContent().getDefinition();
+        CatchEventPropertyWriter p = propertyWriterFactory.of(event);
+
+        BPMNGeneralSet general = definition.getGeneral();
+        p.setName(general.getName().getValue());
+        p.setDocumentation(general.getDocumentation().getValue());
+        p.setSimulationSet(definition.getSimulationSet());
+        p.setBounds(n.getContent().getBounds());
+
+        InterruptingConditionalEventExecutionSet executionSet = definition.getExecutionSet();
+        event.setIsInterrupting(executionSet.getIsInterrupting().getValue());
+        p.addCondition(executionSet.getConditionExpression());
+
+        return p;
+    }
+
+    private PropertyWriter escalationEvent(Node<View<StartEscalationEvent>, ?> n) {
+        StartEvent event = bpmn2.createStartEvent();
+        event.setId(n.getUUID());
+
+        StartEscalationEvent definition = n.getContent().getDefinition();
+        CatchEventPropertyWriter p = propertyWriterFactory.of(event);
+
+        BPMNGeneralSet general = definition.getGeneral();
+        p.setName(general.getName().getValue());
+        p.setDocumentation(general.getDocumentation().getValue());
+        p.setSimulationSet(definition.getSimulationSet());
+        p.setBounds(n.getContent().getBounds());
+
+        InterruptingEscalationEventExecutionSet executionSet = definition.getExecutionSet();
+        event.setIsInterrupting(executionSet.getIsInterrupting().getValue());
+        p.addEscalation(executionSet.getEscalationRef());
+
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
+
+        return p;
+    }
+
+    private PropertyWriter compensationEvent(Node<View<StartCompensationEvent>, ?> n) {
+        StartEvent event = bpmn2.createStartEvent();
+        event.setId(n.getUUID());
+
+        StartCompensationEvent definition = n.getContent().getDefinition();
+        CatchEventPropertyWriter p = propertyWriterFactory.of(event);
+
+        event.setIsInterrupting(definition.getIsInterrupting().getValue());
+        p.addCompensation();
+
+        BPMNGeneralSet general = definition.getGeneral();
+        p.setName(general.getName().getValue());
+        p.setDocumentation(general.getDocumentation().getValue());
+        p.setSimulationSet(definition.getSimulationSet());
+        p.setBounds(n.getContent().getBounds());
+        return p;
+    }
+
 }
