@@ -35,14 +35,20 @@ import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.BpmnNo
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.CatchEventPropertyReader;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.EventDefinitionReader;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.PropertyReaderFactory;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateConditionalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateTimerEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.CancelActivity;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.conditional.CancellingConditionalEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.CancellingErrorEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.ErrorRef;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.CancellingEscalationEventExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.EscalationRef;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.CancellingMessageEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.MessageRef;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.CancellingSignalEventExecutionSet;
@@ -78,9 +84,9 @@ public class IntermediateCatchEventConverter {
                         .when(SignalEventDefinition.class, e -> signalEvent(event, e))
                         .when(MessageEventDefinition.class, e -> messageEvent(event, e))
                         .when(ErrorEventDefinition.class, e -> errorEvent(event, e))
-                        .missing(EscalationEventDefinition.class)
-                        .missing(CompensateEventDefinition.class)
-                        .missing(ConditionalEventDefinition.class)
+                        .when(ConditionalEventDefinition.class, e -> conditionalEvent(event, e))
+                        .when(EscalationEventDefinition.class, e -> escalationEvent(event, e))
+                        .when(CompensateEventDefinition.class, e -> compensationEvent(event, e))
                         .apply(eventDefinitions.get(0)).value();
             default:
                 throw new UnsupportedOperationException("Multiple definitions not supported for intermediate catch event");
@@ -99,9 +105,9 @@ public class IntermediateCatchEventConverter {
                         .when(TimerEventDefinition.class, e -> timerEvent(event, e))
                         .when(MessageEventDefinition.class, e -> messageEvent(event, e))
                         .when(ErrorEventDefinition.class, e -> errorEvent(event, e))
-                        .missing(EscalationEventDefinition.class)
-                        .missing(CompensateEventDefinition.class)
-                        .missing(ConditionalEventDefinition.class)
+                        .when(ConditionalEventDefinition.class, e -> conditionalEvent(event, e))
+                        .when(EscalationEventDefinition.class, e -> escalationEvent(event, e))
+                        .when(CompensateEventDefinition.class, e -> compensationEvent(event, e))
                         .apply(eventDefinitions.get(0)).value()
                         .docked();
             default:
@@ -224,4 +230,85 @@ public class IntermediateCatchEventConverter {
 
         return BpmnNode.of(node);
     }
+
+    private BpmnNode conditionalEvent(CatchEvent event, ConditionalEventDefinition e) {
+        String nodeId = event.getId();
+        Node<View<IntermediateConditionalEvent>, Edge> node = factoryManager.newNode(nodeId, IntermediateConditionalEvent.class);
+
+        IntermediateConditionalEvent definition = node.getContent().getDefinition();
+        CatchEventPropertyReader p = propertyReaderFactory.of(event);
+
+        definition.setGeneral(new BPMNGeneralSet(
+                new Name(p.getName()),
+                new Documentation(p.getDocumentation())
+        ));
+
+        definition.setExecutionSet(new CancellingConditionalEventExecutionSet(
+                new CancelActivity(p.isCancelActivity()),
+                p.getConditionExpression(e)
+        ));
+
+        node.getContent().setBounds(p.getBounds());
+
+        definition.setDimensionsSet(p.getCircleDimensionSet());
+        definition.setFontSet(p.getFontSet());
+        definition.setBackgroundSet(p.getBackgroundSet());
+
+        return BpmnNode.of(node);
+    }
+
+    private BpmnNode escalationEvent(CatchEvent event,
+                                     EscalationEventDefinition e) {
+        String nodeId = event.getId();
+        Node<View<IntermediateEscalationEvent>, Edge> node = factoryManager.newNode(nodeId,
+                                                                                    IntermediateEscalationEvent.class);
+
+        IntermediateEscalationEvent definition = node.getContent().getDefinition();
+        CatchEventPropertyReader p = propertyReaderFactory.of(event);
+
+        definition.setGeneral(new BPMNGeneralSet(
+                new Name(p.getName()),
+                new Documentation(p.getDocumentation())
+        ));
+
+        definition.setDataIOSet(
+                new DataIOSet(p.getAssignmentsInfo()));
+
+        definition.setExecutionSet(new CancellingEscalationEventExecutionSet(
+                new CancelActivity(p.isCancelActivity()),
+                new EscalationRef(EventDefinitionReader.escalationRefOf(e))
+        ));
+
+        node.getContent().setBounds(p.getBounds());
+
+        definition.setDimensionsSet(p.getCircleDimensionSet());
+        definition.setFontSet(p.getFontSet());
+        definition.setBackgroundSet(p.getBackgroundSet());
+
+        return BpmnNode.of(node);
+    }
+
+    private BpmnNode compensationEvent(CatchEvent event,
+                                       CompensateEventDefinition e) {
+        String nodeId = event.getId();
+        Node<View<IntermediateCompensationEvent>, Edge> node = factoryManager.newNode(nodeId,
+                                                                                      IntermediateCompensationEvent.class);
+
+        IntermediateCompensationEvent definition = node.getContent().getDefinition();
+        CatchEventPropertyReader p = propertyReaderFactory.of(event);
+
+        definition.setGeneral(new BPMNGeneralSet(
+                new Name(p.getName()),
+                new Documentation(p.getDocumentation())
+        ));
+
+        node.getContent().setBounds(p.getBounds());
+
+        definition.setDimensionsSet(p.getCircleDimensionSet());
+        definition.setFontSet(p.getFontSet());
+        definition.setBackgroundSet(p.getBackgroundSet());
+
+        return BpmnNode.of(node);
+    }
+
 }
