@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.bpmn.client.forms.fields.assignmentsEditor;
 
 import java.util.List;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -75,6 +76,8 @@ public class ActivityDataIOEditorWidgetViewImpl extends Composite implements Act
     @Inject
     protected Event<NotificationEvent> notification;
 
+    private boolean readOnly = false;
+
     @Override
     public void init(final Presenter presenter) {
         this.presenter = presenter;
@@ -138,6 +141,7 @@ public class ActivityDataIOEditorWidgetViewImpl extends Composite implements Act
     @Override
     public void setAssignmentRows(final List<AssignmentRow> rows) {
         assignments.setValue(rows);
+        setReadOnly(readOnly);
     }
 
     @Override
@@ -150,6 +154,15 @@ public class ActivityDataIOEditorWidgetViewImpl extends Composite implements Act
         return assignments.getComponent(index);
     }
 
+    @Override
+    public void setReadOnly(final boolean readOnly) {
+        this.readOnly = readOnly;
+        addVarButton.setEnabled(!readOnly);
+        for (int i = 0; i < getAssignmentsCount(); i++) {
+            getAssignmentWidget(i).setReadOnly(readOnly);
+        }
+    }
+
     @EventHandler("addVarButton")
     public void handleAddVarButton(final ClickEvent e) {
         presenter.handleAddClick();
