@@ -28,9 +28,10 @@ import org.kie.workbench.common.stunner.client.widgets.popups.PopupUtil;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
 import org.kie.workbench.common.stunner.core.client.session.command.ClientSessionCommand;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditor;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditorTest;
-import org.kie.workbench.common.stunner.project.client.editor.ProjectEditorMenuSessionItems;
+import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectEditorMenuSessionItems;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -87,6 +88,9 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
     private BPMNDiagramEditor diagramEditor;
 
+    @Mock
+    private DocumentationView documentationView;
+
     @Before
     @SuppressWarnings("unchecked")
     public void setUp() {
@@ -107,7 +111,7 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     }
 
     @Override
-    protected ProjectEditorMenuSessionItems getMenuSessionItems() {
+    protected AbstractProjectEditorMenuSessionItems getMenuSessionItems() {
         return bpmnMenuSessionItems;
     }
 
@@ -123,6 +127,7 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Override
     protected AbstractProjectDiagramEditor createDiagramEditor() {
         diagramEditor = spy(new BPMNDiagramEditor(view,
+                                                  documentationView,
                                                   placeManager,
                                                   errorPopupPresenter,
                                                   changeTitleNotificationEvent,
@@ -142,6 +147,8 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
                                                   popupUtil,
                                                   xmlEditorView) {
             {
+                docks = defaultEditorDock;
+                perspectiveManager = perspectiveManagerMock;
                 fileMenuBuilder = BPMNDiagramEditorTest.this.fileMenuBuilder;
                 workbenchContext = BPMNDiagramEditorTest.this.workbenchContext;
                 projectController = BPMNDiagramEditorTest.this.projectController;
