@@ -16,7 +16,9 @@
 
 package org.kie.workbench.common.stunner.cm.client.command;
 
+import java.util.Collections;
 import java.util.Optional;
+import java.util.OptionalInt;
 
 import org.kie.workbench.common.stunner.cm.client.command.canvas.CaseManagementSetChildNodeCanvasCommand;
 import org.kie.workbench.common.stunner.cm.client.command.graph.CaseManagementSetChildNodeGraphCommand;
@@ -27,38 +29,42 @@ import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 
-public class CaseManagementSetChildCommand extends org.kie.workbench.common.stunner.core.client.canvas.command.SetChildNodeCommand {
+public class CaseManagementSetChildCommand extends org.kie.workbench.common.stunner.core.client.canvas.command.SetChildrenCommand {
 
-    protected final Optional<Integer> index;
+    protected final OptionalInt index;
     protected final Optional<Node> originalParent;
-    protected final Optional<Integer> originalIndex;
+    protected final OptionalInt originalIndex;
 
     public CaseManagementSetChildCommand(final Node parent,
                                          final Node child) {
         this(parent,
              child,
-             Optional.of(0),
+             OptionalInt.of(parent.getOutEdges().size()),
              Optional.empty(),
-             Optional.empty());
+             OptionalInt.empty());
     }
 
     public CaseManagementSetChildCommand(final Node parent,
                                          final Node child,
-                                         final Optional<Integer> index,
+                                         final OptionalInt index,
                                          final Optional<Node> originalParent,
-                                         final Optional<Integer> originalIndex) {
+                                         final OptionalInt originalIndex) {
         super(parent,
-              child);
+              Collections.singleton(child));
         this.index = index;
         this.originalParent = originalParent;
         this.originalIndex = originalIndex;
     }
 
+    public Node getCandidate() {
+        return getCandidates().iterator().next();
+    }
+
     @Override
     @SuppressWarnings("unchecked")
     protected Command<GraphCommandExecutionContext, RuleViolation> newGraphCommand(final AbstractCanvasHandler context) {
         return new CaseManagementSetChildNodeGraphCommand(parent,
-                                                          candidate,
+                                                          getCandidate(),
                                                           index,
                                                           originalParent,
                                                           originalIndex);
@@ -67,7 +73,7 @@ public class CaseManagementSetChildCommand extends org.kie.workbench.common.stun
     @Override
     protected AbstractCanvasCommand newCanvasCommand(final AbstractCanvasHandler context) {
         return new CaseManagementSetChildNodeCanvasCommand(parent,
-                                                           candidate,
+                                                           getCandidate(),
                                                            index,
                                                            originalParent,
                                                            originalIndex);
