@@ -20,10 +20,13 @@ import org.junit.Before;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.impl.AbstractElementBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
+import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationMessages;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.EventSourceMock;
 
+import static org.mockito.Mockito.mock;
+
 @RunWith(MockitoJUnitRunner.class)
 public class CaseManagementObserverBuilderControlTest extends BaseCaseManagementBuilderControlTest {
 
@@ -40,11 +43,10 @@ public class CaseManagementObserverBuilderControlTest extends BaseCaseManagement
     protected AbstractElementBuilderControl getBuilderControl() {
         return new CaseManagementObserverBuilderControl(clientDefinitionManager,
                                                         clientFactoryServices,
-                                                        graphUtils,
                                                         ruleManager,
                                                         canvasCommandFactory,
+                                                        mock(ClientTranslationMessages.class),
                                                         graphBoundsIndexer,
-                                                        canvasLayoutUtils,
                                                         selectionEvent);
     }
 }
