@@ -23,7 +23,6 @@ import javax.inject.Inject;
 import com.google.gwt.user.client.ui.IsWidget;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
-import org.kie.workbench.common.stunner.bpmn.factory.BPMNGraphFactory;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
 import org.kie.workbench.common.stunner.cm.project.client.type.CaseManagementDiagramResourceType;
@@ -32,8 +31,8 @@ import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHand
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditor;
-import org.kie.workbench.common.stunner.project.client.editor.ProjectEditorMenuSessionItems;
 import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramFocusEvent;
 import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramLoseFocusEvent;
 import org.kie.workbench.common.stunner.project.client.screens.ProjectMessagesListener;
@@ -68,6 +67,7 @@ public class CaseManagementDiagramEditor extends AbstractProjectDiagramEditor<Ca
 
     @Inject
     public CaseManagementDiagramEditor(final AbstractProjectDiagramEditor.View view,
+                                       final DocumentationView documentationView,
                                        final PlaceManager placeManager,
                                        final ErrorPopupPresenter errorPopupPresenter,
                                        final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
@@ -76,7 +76,7 @@ public class CaseManagementDiagramEditor extends AbstractProjectDiagramEditor<Ca
                                        final ClientProjectDiagramService projectDiagramServices,
                                        final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances,
                                        final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances,
-                                       final ProjectEditorMenuSessionItems menuSessionItems,
+                                       final CaseManagementProjectEditorMenuSessionItems menuSessionItems,
                                        final Event<OnDiagramFocusEvent> onDiagramFocusEvent,
                                        final Event<OnDiagramLoseFocusEvent> onDiagramLostFocusEvent,
                                        final ProjectMessagesListener projectMessagesListener,
@@ -85,6 +85,7 @@ public class CaseManagementDiagramEditor extends AbstractProjectDiagramEditor<Ca
                                        final TextEditorView xmlEditorView,
                                        final Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller) {
         super(view,
+              documentationView,
               placeManager,
               errorPopupPresenter,
               changeTitleNotificationEvent,
@@ -110,16 +111,6 @@ public class CaseManagementDiagramEditor extends AbstractProjectDiagramEditor<Ca
                         place);
     }
 
-    @Override
-    protected int getCanvasWidth() {
-        return (int) BPMNGraphFactory.GRAPH_DEFAULT_WIDTH;
-    }
-
-    @Override
-    protected int getCanvasHeight() {
-        return (int) BPMNGraphFactory.GRAPH_DEFAULT_HEIGHT;
-    }
-
     @Override
     protected String getEditorIdentifier() {
         return CaseManagementDiagramEditor.EDITOR_ID;
@@ -131,8 +122,10 @@ public class CaseManagementDiagramEditor extends AbstractProjectDiagramEditor<Ca
     }
 
     @OnClose
+    @Override
     public void onClose() {
         super.doClose();
+        super.onClose();
     }
 
     @OnFocus
